(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     76096,       2049]
NotebookOptionsPosition[     73391,       1948]
NotebookOutlinePosition[     73780,       1965]
CellTagsIndexPosition[     73737,       1962]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Complex Number Addition and the Complex (",
 StyleBox[ButtonBox["Argand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ArgandDiagram.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ArgandDiagram.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 ") Plane, Activity 1"
}], "Title",
 CellChangeTimes->{{3.6276539583894243`*^9, 3.627653977623808*^9}, {
  3.6276540216568527`*^9, 3.6276540406690397`*^9}, {3.627660012060422*^9, 
  3.6276600131435823`*^9}, {3.6280071117279673`*^9, 3.6280071130225677`*^9}, {
  3.630425059429665*^9, 3.630425061817275*^9}}],

Cell[CellGroupData[{

Cell["Learning Goals:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}, {3.678540619338686*^9, 3.678540619597479*^9}}],

Cell[TextData[{
 "1) See that one \[OpenCurlyDoubleQuote]natural\[CloseCurlyDoubleQuote] view \
of complex numbers as linear \[OpenCurlyDoubleQuote]polynomials\
\[CloseCurlyDoubleQuote], with real number coefficients, in the ",
 StyleBox[ButtonBox["indeterminate",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Indeterminate_(variable)"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Indeterminate_(variable)"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " \[ImaginaryI] (forgetting, for the moment, that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ImaginaryI]", "2"], "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]]],
 ") leads to \n\t(a) a definition of complex number addition that is \
reasonable algebraically and\n\t(b) a reasonable geometric interpretation of \
complex numbers as points in a plane, analogous to the geometric \
interpretation of real numbers as points on a line.\n\t\n2) Learn basic \
applications of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions ",
 StyleBox[ButtonBox["ComplexExpand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ComplexExpand.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ComplexExpand.html"],
  
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and ",
 StyleBox[ButtonBox["Show",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Show.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Show.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " in this setting, as well as various ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " formatting options"
}], "Subsection",
 CellChangeTimes->{{3.629471283194976*^9, 3.629471449316176*^9}, {
   3.629471491689554*^9, 3.629471495629924*^9}, 3.629471704802578*^9, {
   3.6294717887322683`*^9, 3.629471791315475*^9}, 3.629471883527823*^9, {
   3.630073557592288*^9, 3.630073561685176*^9}, {3.6478701952830887`*^9, 
   3.647870200985578*^9}, {3.647870236097437*^9, 3.6478702457649117`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prerequisites:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
   3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
   3.629471286589877*^9}, {3.62947861284763*^9, 3.629478616140943*^9}, 
   3.647877110832814*^9}],

Cell["\<\
1) Some comfort with abstract algebra, though not necessarily at the level of \
a course in abstract algebra

2) A basic familiarity with complex numbers in precalculus or calculus is \
helpful

3) Understanding of the way points are described in a rectangular (Cartesian) \
coordinate system\
\>", "Subsection",
 CellChangeTimes->{{3.629471283194976*^9, 3.629471449316176*^9}, {
   3.629471491689554*^9, 3.629471495629924*^9}, 3.629471704802578*^9, {
   3.6294717887322683`*^9, 3.629471791315475*^9}, 3.629471883527823*^9, {
   3.629478639313504*^9, 3.629478679493908*^9}, {3.629478720658692*^9, 
   3.629478816037221*^9}, {3.647953675967849*^9, 3.6479536776528473`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction: ", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}, {3.6294714662738123`*^9, 3.629471468263523*^9}, {
  3.630073613440137*^9, 3.630073624429462*^9}}],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["arithmetic",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Arithmetic"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Arithmetic"],
  FontColor->RGBColor[0, 0, 1]],
 " of ",
 StyleBox[ButtonBox["complex numbers",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex_number"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex_number"],
  FontColor->RGBColor[0, 0, 1]],
 ", which leads to deeper subject of ",
 StyleBox[ButtonBox["complex analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex_analysis"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex_analysis"],
  FontColor->RGBColor[0, 0, 1]],
 " (calculus-related ideas and tools for understanding ",
 StyleBox[ButtonBox["complex functions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex-valued_function"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex-valued_function"],
  FontColor->RGBColor[0, 0, 1]],
 "), can be thought about and worked through in ",
 StyleBox[ButtonBox["purely symbolic rule-based (formal) ways",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Formalism_(mathematics)"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Formalism_(mathematics)"],
  FontColor->RGBColor[0, 0, 1]],
 ".  However, as with many areas of mathematics, the geometry of ",
 StyleBox[ButtonBox["complex arithmetic",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://betterexplained.com/articles/intuitive-arithmetic-with-\
complex-numbers/"], None},
  ButtonNote->
   "http://betterexplained.com/articles/intuitive-arithmetic-with-complex-\
numbers/"],
  FontColor->RGBColor[0, 0, 1]],
 " gives the symbolic ",
 StyleBox[ButtonBox["mathematical statements of fact",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Theorem"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Theorem"],
  FontColor->RGBColor[0, 0, 1]],
 " richer meaning, leads to new insights, and informs possible ",
 StyleBox[ButtonBox["real-world applications",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathigon.org/mathigon_org/panorama/"], None},
  ButtonNote->"http://mathigon.org/mathigon_org/panorama/"],
  FontColor->RGBColor[0, 0, 1]],
 ".  This module, \[OpenCurlyDoubleQuote]Complex Number Addition and the \
Complex (",
 StyleBox[ButtonBox["Argand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ArgandDiagram.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ArgandDiagram.html"],
  FontColor->RGBColor[0, 0, 1]],
 ") Plane\[CloseCurlyDoubleQuote], provides an introduction to the marriage \
of the symbolic and the geometric within the study of complex arithmetic, \
providing a solid foundation for work in ",
 StyleBox[ButtonBox["complex analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex_analysis"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex_analysis"],
  FontColor->RGBColor[0, 0, 1]],
 ".  Activity 1 of this module focuses on the basic correspondence between a \
given complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " and the point ",
 StyleBox["z",
  FontSlant->"Italic"],
 " in the plane whose ",
 StyleBox[ButtonBox["rectangular (Cartesian) coordinates",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Cartesian_coordinate_system"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Cartesian_coordinate_system"],
  FontColor->RGBColor[0, 0, 1]],
 " are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 ".  When this correspondence is specified and the axes are labeled with the \
words \[OpenCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] (horizontal) and \
\[OpenCurlyDoubleQuote]imaginary\[CloseCurlyDoubleQuote] (vertical), the \
plane is then called \[OpenCurlyDoubleQuote]the\[CloseCurlyDoubleQuote] ",
 StyleBox[ButtonBox["complex plane",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex_plane"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex_plane"],
  FontColor->RGBColor[0, 0, 1]],
 ", or sometimes the ",
 StyleBox[ButtonBox["Argand plane",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ArgandPlane.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ArgandPlane.html"],
  FontColor->RGBColor[0, 0, 1]],
 ", in honor of the Swiss mathematician ",
 StyleBox[ButtonBox["Jean-Robert Argand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Jean-Robert_Argand"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Jean-Robert_Argand"],
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.6304183274365187`*^9, 3.630418632279633*^9}, {
  3.630418697250352*^9, 3.630418701773437*^9}, {3.6304187693186607`*^9, 
  3.630418769321042*^9}, {3.63041883960098*^9, 3.630418901440366*^9}, {
  3.630418952732256*^9, 3.630418965072918*^9}, {3.630418996273047*^9, 
  3.6304190678720512`*^9}, {3.630419411193425*^9, 3.630419648870229*^9}, {
  3.630419693480446*^9, 3.630419693483626*^9}, {3.647870451615673*^9, 
  3.647870471492469*^9}, {3.647870639638309*^9, 3.647870698250945*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Content:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}, {3.6294714662738123`*^9, 3.629471468263523*^9}}],

Cell[TextData[{
 "Complex numbers can be viewed in purely algebraic and symbolic ways, which \
is where we start in this first activity of a learning module on complex \
addition and the complex plane.  However, our main goal in this learning \
module is to see that there are natural ",
 StyleBox["geometric",
  FontSlant->"Italic"],
 " ways of viewing complex numbers, and that this mode of thought is a \
powerful tool for understanding and problem-solving.  This is most typically \
done with either ",
 StyleBox[ButtonBox["rectangular",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Cartesian_coordinate_system"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Cartesian_coordinate_system"],
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox[ButtonBox["polar",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Polar_coordinate_system"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Polar_coordinate_system"],
  FontColor->RGBColor[0, 0, 1]],
 " coordinates, and you will need to become very familiar with translating \
between these two coordinate systems if you want to be successful in \
understanding and using complex numbers and complex functions."
}], "Text",
 CellChangeTimes->{{3.630073667779408*^9, 3.630073914845625*^9}, {
  3.647870717155521*^9, 3.6478707944513903`*^9}}],

Cell[TextData[{
 StyleBox[ButtonBox["Algebraic expressions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.themathpage.com/alg/algebraic-expressions.htm"], None},
  ButtonNote->"http://www.themathpage.com/alg/algebraic-expressions.htm"],
  FontColor->RGBColor[0, 0, 1]],
 " are combinations of symbols, such as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"6", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"5", "x", " ", "y"}], "+", 
    SuperscriptBox["y", "3"], "+", 
    RowBox[{
     FractionBox["2", "3"], "x"}], "+", "z", "+", 
    RowBox[{"3", "z"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["z", "5"], "-", 
    RowBox[{"11", "y", " ", "x"}], "+", 
    RowBox[{"2", "x"}], "+", 
    RowBox[{"x", "(", 
     RowBox[{"4", "+", "x"}], ")"}]}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     SuperscriptBox["x", "2"], "y"], "+", 
    FractionBox[
     SuperscriptBox["x", "3"], "x"]}], TraditionalForm]]],
 ", that combine numbers and variables using operations from arithmetic, such \
as addition, subtraction, multiplication, and division \[LongDash] other \
operations that are sometimes allowed include things such as square roots, \
cube roots, and more exotic kinds of mathematical objects. The variables can \
be thought of as pure symbols with no meaning, but we usually think of them \
as representing numbers, and we usually are interested in determining what \
happens to the values of these expressions as the variables are allowed to \
change, or \[OpenCurlyDoubleQuote]vary\[CloseCurlyDoubleQuote]. In other \
words, we typically want to think of them as defining ",
 StyleBox[ButtonBox["functions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Function_(mathematics)"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Function_(mathematics)"],
  FontColor->RGBColor[0, 0, 1]],
 " and then use our mathematical knowledge and tools to analyze the behavior \
of those functions.  In mathematics classes, this is often a purely mental \
exercise, but it forms the foundation for nearly all advanced applications of \
mathematics, including in the physical sciences, the social sciences, \
computer science, medicine, engineering, finance, and statistics."
}], "Text",
 CellChangeTimes->{{3.6276544638910522`*^9, 3.627654921618792*^9}, {
  3.627654953987253*^9, 3.627655134176111*^9}, {3.627655194703266*^9, 
  3.627655209837347*^9}, {3.627655250230563*^9, 3.627655279668812*^9}, {
  3.6276553116190243`*^9, 3.627655331808749*^9}, {3.6276553628027782`*^9, 
  3.62765536305539*^9}, {3.627655438567178*^9, 3.627655438570181*^9}, {
  3.6276554959195538`*^9, 3.627655511174876*^9}, {3.6276556418487177`*^9, 
  3.627655674424116*^9}, {3.627655722822695*^9, 3.627655747228941*^9}, {
  3.6276557879147882`*^9, 3.627655793753824*^9}, {3.627655844144212*^9, 
  3.6276558869076223`*^9}, {3.627656993685939*^9, 3.627656995104754*^9}, {
  3.627659375723448*^9, 3.627659377855976*^9}, {3.627907927584279*^9, 
  3.627908029154234*^9}, {3.628874881334854*^9, 3.6288749391920156`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Discussion 1:",
  FontWeight->"Bold"],
 "  How should the expressions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], ",", 
    RowBox[{
     RowBox[{"6", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"5", "x", " ", "y"}], "+", 
     SuperscriptBox["y", "3"], "+", 
     RowBox[{
      FractionBox["2", "3"], "x"}], "-", "z", "+", 
     RowBox[{"3", "z"}]}], ",", 
    RowBox[{
     FractionBox["z", "5"], "-", 
     RowBox[{"11", "y", " ", "x"}], "+", 
     RowBox[{"2", "x"}], "+", 
     RowBox[{"x", "(", 
      RowBox[{"4", "+", "x"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"and", 
      FractionBox[
       SuperscriptBox["x", "2"], "y"]}], "+", 
     FractionBox[
      SuperscriptBox["x", "3"], "x"]}]}], TraditionalForm]]],
 " be simplified, if at all?  How should arithmetic (addition, subtraction, \
multiplication, and division) be performed and simplification be done? (",
 StyleBox["Hints:",
  FontWeight->"Bold"],
 " recall what \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["like terms",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathsisfun.com/algebra/like-terms.html"], None},
  ButtonNote->"http://www.mathsisfun.com/algebra/like-terms.html"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["common denominators",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathsisfun.com/numbers/common-denominator.html"], None},
  ButtonNote->"http://www.mathsisfun.com/numbers/common-denominator.html"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] are.  Also recall the ",
 StyleBox[ButtonBox["distributive property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Distributive_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Distributive_property"],
  FontColor->RGBColor[0, 0, 1]],
 " and the ",
 StyleBox[ButtonBox["rules for exponents",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.purplemath.com/modules/exponent.htm"], None},
  ButtonNote->"http://www.purplemath.com/modules/exponent.htm"],
  FontColor->RGBColor[0, 0, 1]],
 ").  Write down some sample computations and simplifications using the given \
expressions.  How does this work correspond to the properties of the \
arithmetic of the ",
 StyleBox[ButtonBox["real numbers",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Real_number"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Real_number"],
  FontColor->RGBColor[0, 0, 1]],
 "?  For example, are you using the ",
 StyleBox[ButtonBox["commutative property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Commutative_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Commutative_property"],
  FontColor->RGBColor[0, 0, 1]],
 " for addition or multiplication anywhere?"
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
  3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
  3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
  3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
  3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
  3.627657492593141*^9, 3.6276575163946*^9}, {3.627659369469182*^9, 
  3.627659372254017*^9}, {3.6279081214851007`*^9, 3.627908138201469*^9}, {
  3.627908171701682*^9, 3.6279082835834637`*^9}, {3.627908355561986*^9, 
  3.627908496036009*^9}, {3.62790879589528*^9, 3.627908795898261*^9}, {
  3.647871039181404*^9, 3.647871044573051*^9}}],

Cell[CellGroupData[{

Cell["Response 1: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grader/Instructor Response 1: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.62765961929755*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell["\<\
The main point of Discussion 1 is that we do indeed often treat expressions \
as if the variables represent numbers; and indeed, we often use properties of \
real numbers to simplify these expressions and arithmetic combinations of \
these expressions.  If you are at a point in your mathematical education \
where you can do such operations without much thought, that is a sign that \
you have internalized much of your pre-college mathematics well.  \
\>", "Text",
 CellChangeTimes->{{3.627658719107088*^9, 3.627658784867366*^9}, {
  3.627658889349979*^9, 3.62765892162006*^9}, {3.6276589710657177`*^9, 
  3.62765897108265*^9}, {3.627659002581394*^9, 3.627659053400085*^9}, {
  3.627659092197673*^9, 3.627659092200029*^9}, {3.627659131019465*^9, 
  3.627659159258582*^9}, {3.627659194021532*^9, 3.627659236063088*^9}, {
  3.6276592849170923`*^9, 3.6276592929284286`*^9}, {3.627659401231691*^9, 
  3.627659404516089*^9}, {3.627908540015504*^9, 3.6279086290492496`*^9}, {
  3.628875035777446*^9, 3.628875036539165*^9}, {3.647871072116899*^9, 
  3.647871157026165*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do purely symbolic arithmetic, based on these assumptions, though \
sometimes we must use the built-in symbolic manipulation functions ",
 StyleBox[ButtonBox["Expand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Expand.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Expand.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Simplify",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Simplify.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Simplify.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["FullSimplify",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/FullSimplify.html"], None},
  
  ButtonNote->"http://reference.wolfram.com/language/ref/FullSimplify.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Together",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Together.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Together.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Apart",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Apart.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Apart.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", or ",
 StyleBox[ButtonBox["Factor",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Factor.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Factor.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " to get the answer into a form that we want.  Enter each of the following \
three lines of code to see examples of this."
}], "Text",
 CellChangeTimes->{
  3.647871166278544*^9, {3.647871305866301*^9, 3.647871325965828*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"x", "^", "2"}], "y"], "+", 
  FractionBox[
   RowBox[{"x", "^", "3"}], "x"]}]], "Input",
 CellChangeTimes->{{3.647871290674178*^9, 3.647871296191863*^9}}],

Cell[BoxData[
 RowBox[{"Together", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"x", "^", "2"}], "y"], "+", 
   FractionBox[
    RowBox[{"x", "^", "3"}], "x"]}], "]"}]], "Input",
 CellChangeTimes->{{3.627659394788508*^9, 3.6276594187173862`*^9}, {
  3.647871246404592*^9, 3.647871253870778*^9}}],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"x", "^", "2"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "2"}], "/", "y"}], "+", 
     RowBox[{
      RowBox[{"x", "^", "3"}], "/", "x"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627662600656457*^9, 3.627662624758122*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" Exercise 1:",
  FontWeight->"Bold"],
 "  Experiment with the arithmetic operations ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", 
    RowBox[{",", 
     RowBox[{"-", 
      RowBox[{",", 
       RowBox[{"*", 
        RowBox[{",", "/"}]}]}]}]}]}], TraditionalForm]]],
 " and the built-in symbolic manipulation functions mentioned in the \
preceding paragraph on the expressions in Discussion 1 to determine what \
these ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions do.  Check ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s answers by hand.  Are ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s answers always in the form you would leave your answers?"
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
  3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
  3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
  3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
  3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
  3.627657492593141*^9, 3.6276575163946*^9}, {3.627659108756077*^9, 
  3.627659190362417*^9}, {3.627908677348465*^9, 3.6279087177368393`*^9}, {
  3.62887512976138*^9, 3.628875179245981*^9}, {3.628875231758624*^9, 
  3.628875233478917*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Work 1: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659434447322*^9, 3.627659440180417*^9}, {3.627659519063675*^9, 
  3.6276595191998262`*^9}}],

Cell[TextData[{
 StyleBox["(Enter your code under this cell when ",
  FontWeight->"Bold"],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" is in \[OpenCurlyDoubleQuote]Input mode\[CloseCurlyDoubleQuote] \
\[LongDash] make sure a horizontal line is showing before you start typing)",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659460201036*^9, 3.627659504551834*^9}},
 FontColor->RGBColor[0, 0.67, 0]],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}},
 FontColor->RGBColor[0, 0.67, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Grader/Instructor ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Assessment 1: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.627659649751532*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "Initially, on a purely symbolic level, any ",
 StyleBox[ButtonBox["complex number",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex_number"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex_number"],
  FontColor->RGBColor[0, 0, 1]],
 ", such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "+", 
    RowBox[{"3", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", can be thought of as just an expression in the \
\[OpenCurlyDoubleQuote]variable\[CloseCurlyDoubleQuote] \[ImaginaryI], \
completely ignoring the fact that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ImaginaryI]", "2"], "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]]],
 ".  The meaning of the word \[OpenCurlyDoubleQuote]variable\
\[CloseCurlyDoubleQuote] here is a bit of a misnomer, however.  We don\
\[CloseCurlyQuote]t want to allow \[ImaginaryI] to take on different values.  \
It might be better to use a different word for the role that \[ImaginaryI] \
plays here; mathematicians often use the word \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["indeterminate",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Indeterminate_%28variable%29"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Indeterminate_%28variable%29"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] instead."
}], "Text",
 CellChangeTimes->{{3.6276568889840937`*^9, 3.6276569418882113`*^9}, {
  3.627657673966083*^9, 3.627657690980295*^9}, {3.627658432152196*^9, 
  3.627658538113209*^9}, {3.627658585055251*^9, 3.62765861342761*^9}, {
  3.627659706344949*^9, 3.6276597065415277`*^9}, {3.627908764043284*^9, 
  3.627908764045835*^9}, {3.62790881820674*^9, 3.6279088304672832`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Discussion 2:",
  FontWeight->"Bold"],
 "  Based on the view of a complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", where ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " are ",
 StyleBox[ButtonBox["real numbers",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/RealNumber.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/RealNumber.html"],
  FontColor->RGBColor[0, 0, 1]],
 ", as just an expression in the indeterminate \[ImaginaryI], describe how \
the addition of two or more complex numbers should be done.  Give examples.  \
Write down a general formula for the sum of two arbitrary complex numbers, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "+", 
    RowBox[{"d", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", where ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", ",
 StyleBox["c",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["d",
  FontSlant->"Italic"],
 " are arbitrary real numbers (often written ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"d", "\[Element]", "\[DoubleStruckCapitalR]"}]}], 
   TraditionalForm]]],
 " and read \[OpenCurlyDoubleQuote]",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", ",
 StyleBox["c",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["d",
  FontSlant->"Italic"],
 " are all elements of the set of real numbers \[DoubleStruckCapitalR]\
\[CloseCurlyDoubleQuote]).  Does your definition of complex number addition \
satisfy the ",
 StyleBox[ButtonBox["associative property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Associative_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Associative_property"],
  FontColor->RGBColor[0, 0, 1]],
 "?  The ",
 StyleBox[ButtonBox["commutative property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Commutative_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Commutative_property"],
  FontColor->RGBColor[0, 0, 1]],
 "?  Why or why not?  Base your answer to this last question on related facts \
about real number arithmetic.  What role does the complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "+", 
    RowBox[{"0", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " play?  For a given complex number, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", what can you say about the related complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "a"}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "b"}], ")"}], "\[ImaginaryI]"}]}], TraditionalForm]]],
 "?  Is the set of real numbers \[DoubleStruckCapitalR] a subset of the set \
of complex numbers \[DoubleStruckCapitalC]?  If not, is there a \
\[OpenCurlyDoubleQuote]natural\[CloseCurlyDoubleQuote] way to \
\[OpenCurlyDoubleQuote]associate\[CloseCurlyDoubleQuote] \
\[DoubleStruckCapitalR] with some subset of \[DoubleStruckCapitalC].  Are \
there other \[OpenCurlyDoubleQuote]natural ways\[CloseCurlyDoubleQuote] to \
create such as association?  Is one association superior to the others?  Are \
these even good questions to ask in the first place?"
}], "Subsection",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQbbLpi5MJ+2tHNpu9LiD6xenJXiA6be+yGBC9gGPf
cRC96hrfFRCdZ9R9D0RfyNv0BETXV5a8AdE+ovLfQPShTf6/QTRfTOY/EO1g
ystsCqT3B/PwgehTk/cJgWgX08NgOm1GqCSI/rcWQq8/V6wOol/m7zQD0U88
TtiC6JQ1J51BtFqfhD/YnNUQWiNdPBhEx/89HwuiDXM/PVgPpHdlXX4IojdK
/HsBorPddV6C6PAYg4PtnK8dy5tOgunv664cBdGXN0gdA9FffkWcAdFtMilg
+orNdJ/Duq8dW+9Vx4BoHX6Dj0eB9ItIGzANACl3krw=
  "]],

Cell[CellGroupData[{

Cell["Response 2: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.6276595224736834`*^9, 3.627659522575448*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
   3.627659540480051*^9, 3.6276595418563213`*^9}, {3.627659689579788*^9, 
   3.62765968981131*^9}, 3.627660031273603*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grader/Instructor Response 2: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.62765961929755*^9}, {
  3.627660043703747*^9, 3.627660043838567*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "A capital ",
 StyleBox[ButtonBox["I",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/I.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/I.html"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0.5, 0]],
 " is the most basic way to represent the imaginary unit \[ImaginaryI] in \
input/output mode in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".  ",
 StyleBox[ButtonBox["ComplexExpand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ComplexExpand.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ComplexExpand.html"],
  
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " can be used to confirm or refute your ideas in Discussion 2 above."
}], "Text",
 CellChangeTimes->{{3.627663667163701*^9, 3.627663676151565*^9}, {
   3.627663731420498*^9, 3.627663890126082*^9}, {3.6279089626557817`*^9, 
   3.627908962658252*^9}, 3.630424737403521*^9, {3.6478714722728863`*^9, 
   3.647871476151133*^9}}],

Cell[BoxData[
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", "+", 
     RowBox[{"2", "I"}]}], ")"}], "+", 
   RowBox[{"(", 
    RowBox[{"4", "+", 
     RowBox[{"2", "I"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276637615327377`*^9, 3.6276637745392113`*^9}}],

Cell[BoxData[
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "+", 
     RowBox[{"b", "*", "I"}]}], ")"}], "+", 
   RowBox[{"(", 
    RowBox[{"c", "+", 
     RowBox[{"d", "*", "I"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627663801358947*^9, 3.627663812637382*^9}, {
  3.627663905397036*^9, 3.627663906547554*^9}}],

Cell[TextData[{
 "Do you have any ideas about how the multiplication of two arbitrary complex \
numbers ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "+", 
    RowBox[{"d", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " should be done? Make a conjecture and then see what ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " gives for the answer."
}], "Text",
 CellChangeTimes->{{3.628875374472515*^9, 3.628875428486012*^9}, {
  3.628875507403345*^9, 3.62887551187906*^9}, {3.647871499489142*^9, 
  3.6478715036541147`*^9}}],

Cell[BoxData[
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "+", 
     RowBox[{"b", "*", "I"}]}], ")"}], "*", 
   RowBox[{"(", 
    RowBox[{"c", "+", 
     RowBox[{"d", "*", "I"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6288754299334087`*^9, 3.628875442054089*^9}}],

Cell[TextData[{
 "You can also check that the ",
 StyleBox[ButtonBox["distributive property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Distributive_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Distributive_property"],
  FontColor->RGBColor[0, 0, 1]],
 " works in this setting.  The following cell contains two lines of input \
code that will generate two outputs.  "
}], "Text",
 CellChangeTimes->{{3.628875449318366*^9, 3.628875486047296*^9}, {
  3.647871518440497*^9, 3.647871532316657*^9}}],

Cell[BoxData[{
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "+", 
     RowBox[{"b", "*", "I"}]}], ")"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"d", "*", "I"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"e", "+", 
       RowBox[{"f", "*", "I"}]}], ")"}]}], ")"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"b", "*", "I"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"d", "*", "I"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"b", "*", "I"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"e", "+", 
      RowBox[{"f", "*", "I"}]}], ")"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.627663907582281*^9, 3.627663947751939*^9}}],

Cell[TextData[{
 "Since a complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " is uniquely determined by the values of ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", as well as their role in this expression \[LongDash] next to the \
\[ImaginaryI] or not \[LongDash] it is natural to associate the complex \
number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " (which can also be represented as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"b", " ", "\[ImaginaryI]"}], "+", "a"}], TraditionalForm]]],
 ") with the ",
 StyleBox[ButtonBox["ordered pair",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Ordered_pair"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Ordered_pair"],
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " (which should ",
 StyleBox["not",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " be written as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"b", ",", "a"}], ")"}], TraditionalForm]]],
 ").  When we impose a ",
 StyleBox[ButtonBox["Cartesian (rectangular) coordinate system",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Cartesian_coordinate_system"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Cartesian_coordinate_system"],
  FontColor->RGBColor[0, 0, 1]],
 " on a plane, we can use these ordered pairs to visualize the complex \
numbers as points in this plane in a standard way.  The \
\[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["real part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/RealPart.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/RealPart.html"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 ", of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " \[LongDash]the first coordinate of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " \[LongDash] specifies the horizontal (right/left) perpendicular \
displacement, with respect to the vertical axis, of the number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " as a point in the plane; with positive displacement being to the right and \
negative displacement being to the left. The \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["imaginary part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ImaginaryPart.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ImaginaryPart.html"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 ", of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " \[LongDash]the second coordinate of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " \[LongDash] specifies the vertical (up/down) perpendicular displacement, \
with respect to the horizontal axis, of the number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " as a point in the plane; with positive displacement being upward and \
negative displacement being downward.  When a complex number is plotted in \
the given plane in this way, we call this plane \[OpenCurlyDoubleQuote]the\
\[CloseCurlyDoubleQuote] ",
 StyleBox[ButtonBox["Complex (Argand) Plane",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ComplexPlane.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ComplexPlane.html"],
  FontColor->RGBColor[0, 0, 1]],
 "; we label the horizontal axis to be the ",
 StyleBox[ButtonBox["real axis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/RealAxis.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/RealAxis.html"],
  FontColor->RGBColor[0, 0, 1]],
 " and we label the vertical axis to be the ",
 StyleBox[ButtonBox["imaginary axis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ImaginaryAxis.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ImaginaryAxis.html"],
  FontColor->RGBColor[0, 0, 1]],
 ".  These things can just be thought of as labels, and no philosophical \
objections about the deeper nature of what we are doing need be sustained.  \
Questions about applicability to ",
 StyleBox[ButtonBox["the real world",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Reality"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Reality"],
  FontColor->RGBColor[0, 0, 1]],
 ", however, do need to eventually be addressed."
}], "Text",
 CellChangeTimes->{{3.627657978735114*^9, 3.627658120845636*^9}, {
  3.627658184513383*^9, 3.6276581936991663`*^9}, {3.6276587041979923`*^9, 
  3.6276587076181173`*^9}, {3.627659734862486*^9, 3.627659777052169*^9}, {
  3.627659812917594*^9, 3.627659991349291*^9}, {3.627660114240464*^9, 
  3.6276601168740396`*^9}, {3.6276604155072823`*^9, 3.627660508140432*^9}, {
  3.627660555373166*^9, 3.627660555388114*^9}, {3.627660591367168*^9, 
  3.627660682357828*^9}, {3.627660715624648*^9, 3.627660755190234*^9}, {
  3.627660828604656*^9, 3.627660828608768*^9}, {3.62790903462843*^9, 
  3.627909111181098*^9}, {3.627909156536913*^9, 3.6279092056316338`*^9}, {
  3.627911654057898*^9, 3.627911657414344*^9}, {3.628875592642117*^9, 
  3.6288755929093437`*^9}, {3.647871826150104*^9, 3.647871835498371*^9}}],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the ordered pair ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " is typically represented as a \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["list",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/List.html"],
  FontColor->RGBColor[1, 0.5, 0]],
 "\[CloseCurlyDoubleQuote] with two entries, or elements: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], TraditionalForm]]],
 " (see a summary page of many manipulations that can be done, in a very \
general setting, with all kinds of ",
 StyleBox[ButtonBox["lists in Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/guide/ListManipulation.html"], 
    None},
  ButtonNote->
   "http://reference.wolfram.com/language/guide/ListManipulation.html"],
  FontColor->RGBColor[1, 0.5, 0]],
 ").  These points can then be plotted with ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ".  For instance, we can, as done in ",
 StyleBox[ButtonBox["Figure [1] (Ch. 1.I .1, p. 2) of Tristan Needham\
\[CloseCurlyQuote]s Visual Complex Analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?s=books&ie=UTF8&qid=1419886831&sr=1-1&keywords=visual+\
complex+analysis"], None},
  ButtonNote->
   "http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?s=books&ie=UTF8&qid=1419886831&sr=1-1&keywords=visual+\
complex+analysis"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 ", plot the complex numbers ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"4", "=", 
     RowBox[{"4", "+", 
      RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], ",", " ", 
    RowBox[{"4", "+", 
     RowBox[{"3", "\[ImaginaryI]"}]}], ",", " ", 
    RowBox[{
     RowBox[{"3", "\[ImaginaryI]"}], "=", 
     RowBox[{"0", "+", 
      RowBox[{"3", " ", "\[ImaginaryI]"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "7"}], "+", "\[ImaginaryI]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "7"}], ")"}], "+", 
      RowBox[{"1", " ", "\[ImaginaryI]"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], "-", 
      RowBox[{"3", "\[ImaginaryI]"}]}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "3"}], ")"}], "\[ImaginaryI]"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"and", " ", "2"}], "-", 
      RowBox[{"2", "\[ImaginaryI]"}]}], "=", 
     RowBox[{"2", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], "\[ImaginaryI]"}]}]}]}], TraditionalForm]]],
 " using the code to follow. For efficiency\[CloseCurlyQuote]s sake, we put \
these lists (of two elements each) in a \[OpenCurlyDoubleQuote]list of lists\
\[CloseCurlyDoubleQuote] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}], TraditionalForm]]],
 " (with six total elements) in order to plot them all at once.  Note also \
that the options ",
 StyleBox[ButtonBox["PlotStyle",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/PlotStyle.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/PlotStyle.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/PlotRange.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/PlotRange.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and ",
 StyleBox[ButtonBox["AxesLabel",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/AxesLabel.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/AxesLabel.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 StyleBox[",",
  FontColor->RGBColor[1, 0.5, 0]],
 " can be used to, respectively, make the dots black and larger than normal, \
choose the plotting window, and label the axes.  Note also the use of \
\[OpenCurlyDoubleQuote]",
 StyleBox["InitialFigure1",
  FontWeight->"Bold"],
 " =\[CloseCurlyDoubleQuote] at the beginning of the line will store the \
resulting output graph in a variable we have named ",
 StyleBox["InitialFigure1",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.62766008659522*^9, 3.627660103138002*^9}, {
   3.6276601397144814`*^9, 3.627660188929512*^9}, {3.627660277491293*^9, 
   3.6276604093848667`*^9}, {3.627660846294976*^9, 3.627660894643497*^9}, {
   3.627660931852092*^9, 3.6276610814852037`*^9}, {3.627661117605917*^9, 
   3.62766122600981*^9}, {3.627661421563168*^9, 3.627661606099361*^9}, {
   3.627661670184834*^9, 3.627661688721341*^9}, {3.628875650810205*^9, 
   3.628875650841794*^9}, 3.630424764039959*^9}],

Cell[BoxData[
 RowBox[{"InitialFigure1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "3"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}], "}"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<real\>\"", ",", "\"\<imaginary\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6276610889420233`*^9, 3.6276611061661463`*^9}, {
  3.6276611940880632`*^9, 3.627661260925015*^9}, {3.6276613034521437`*^9, 
  3.627661317608073*^9}, {3.6276613793788347`*^9, 3.6276614154510317`*^9}, {
  3.627661554097768*^9, 3.627661556202138*^9}, {3.627661590985866*^9, 
  3.627661591738063*^9}}],

Cell[TextData[{
 "After the preceding line has been entered, the graph can be displayed again \
by just entering its name ",
 StyleBox["InitialFigure1",
  FontWeight->"Bold"],
 ".",
 StyleBox["  ",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.6276616146676903`*^9, 3.627661656154912*^9}, {
  3.627909319633389*^9, 3.627909324176015*^9}, {3.6478727465528708`*^9, 
  3.6478727513189898`*^9}}],

Cell[BoxData["InitialFigure1"], "Input",
 CellChangeTimes->{{3.627661657728503*^9, 3.6276616593720093`*^9}, {
  3.6288757064887753`*^9, 3.628875709406294*^9}, {3.64787273930554*^9, 
  3.647872741171612*^9}}],

Cell[TextData[{
 "The preceding line of code will not produce the desired output after we \
quit ",
 StyleBox[ButtonBox["Mathematica\[CloseCurlyQuote]s kernel",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Mathematica#Interface"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Mathematica#Interface"],
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 ", either through the ",
 StyleBox["Evaluation menu",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " or by quitting the program.  "
}], "Text",
 CellChangeTimes->{{3.627909329553458*^9, 3.627909362585091*^9}, {
  3.6279094139787893`*^9, 3.627909413980949*^9}, {3.628875726757264*^9, 
  3.628875754995224*^9}, {3.629040652187572*^9, 3.6290406679557247`*^9}}],

Cell[TextData[{
 "Another option, ",
 StyleBox[ButtonBox["GridLines",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/GridLines.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/GridLines.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", can be used to create a standard rectangular grid in the background of \
the picture. The function ",
 StyleBox[ButtonBox["Show",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Show.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Show.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " combines the graphic outputs into one output and the option ",
 StyleBox[ButtonBox["AspectRatio",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/AspectRatio.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/AspectRatio.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " can be used to make the scales on the axes the same."
}], "Text",
 CellChangeTimes->{{3.62766171755234*^9, 3.627661783360642*^9}, {
   3.6276618855495157`*^9, 3.6276619385686483`*^9}, {3.627661971621619*^9, 
   3.6276619995052967`*^9}, 3.6304248651261787`*^9, {3.6478728232134647`*^9, 
   3.647872843099244*^9}, {3.647872877207528*^9, 3.647872894653553*^9}, {
   3.647873071276359*^9, 3.6478730716092577`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"InitialFigure1", ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "9"}], ",", 
        RowBox[{"-", "8"}], ",", 
        RowBox[{"-", "7"}], ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "5"}], ",", 
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2", ",", "3", ",", "4", 
        ",", "5", ",", "6", ",", "7", ",", "8", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2", ",", "3", ",", 
        "4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276617867672367`*^9, 3.627661879246334*^9}, {
   3.627661941781152*^9, 3.627661945291995*^9}, {3.6478728458154373`*^9, 
   3.647872849508155*^9}, 3.647873074524427*^9}],

Cell[TextData[{
 "When there are many grid-lines, the locations of the grid-lines can be \
generated more efficiently with ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", which is the basic list-generating command in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " when the elements of a list have a \[OpenCurlyDoubleQuote]formula\
\[CloseCurlyDoubleQuote].  For example, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Table", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}],
    FontWeight->"Bold"], TraditionalForm]]],
 " generates the list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"-", "7"}], ",", 
     RowBox[{"-", "6"}], ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2", ",", "3", ",", "4", 
     ",", "5", ",", "6", ",", "7", ",", "8", ",", "9"}], "}"}], 
   TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.6276620140095253`*^9, 3.627662105209556*^9}, {
   3.6276621769175787`*^9, 3.627662198061448*^9}, 3.63042482162609*^9, {
   3.647872922834806*^9, 3.6478729261592712`*^9}, {3.647877042590454*^9, 
   3.6478770446862087`*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627662062043561*^9, 3.627662066087792*^9}}],

Cell[TextData[{
 "As a related example, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"i", "^", "2"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], TraditionalForm]],
  FontWeight->"Bold"],
 " makes a list of the squares of the numbers in the preceding list."
}], "Text",
 CellChangeTimes->{{3.62766270160417*^9, 3.6276627227788773`*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"i", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627662062043561*^9, 3.627662066087792*^9}, {
  3.627662728214615*^9, 3.6276627284442883`*^9}}],

Cell[TextData[{
 "Note that lists in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are not the same as sets in Mathematics.  The preceding list is ",
 StyleBox["not",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " equivalent to the ",
 StyleBox["mathematical set",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
    "0", ",", "1", ",", "4", ",", "9", ",", "16", ",", "25", ",", "36", ",", 
     "49", ",", "64", ",", "81"}], "}"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.647872947727357*^9, 3.647872992172153*^9}}],

Cell[TextData[{
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " is very flexible.  It can also generate, for example, lists of points,"
}], "Text",
 CellChangeTimes->{{3.627662756518363*^9, 3.6276627737982597`*^9}, {
   3.627662825098092*^9, 3.627662875864808*^9}, {3.627909529035808*^9, 
   3.62790952935911*^9}, 3.630424872285877*^9}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"i", "^", "3"}], ",", 
     RowBox[{"i", "^", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.62766277689592*^9, 3.62766283773356*^9}}],

Cell["or even lists of graphs.", "Text",
 CellChangeTimes->{{3.627909484395495*^9, 3.627909488496395*^9}, {
  3.627909531191312*^9, 3.627909531471408*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"x", "^", 
      RowBox[{"(", "i", ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", ".5", ",", "2", ",", ".5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6279094904566317`*^9, 3.627909518653182*^9}}],

Cell["\<\
We now have a way to create the graph of the complex numbers in the complex \
plane more efficiently (especially through the use of \
\[OpenCurlyDoubleQuote]Copy & Paste\[CloseCurlyDoubleQuote] to save typing \
time).\
\>", "Text",
 CellChangeTimes->{{3.627662107856578*^9, 3.627662128007699*^9}, {
   3.6276626633089943`*^9, 3.627662666456585*^9}, {3.627909550275042*^9, 
   3.6279095578159103`*^9}, {3.64787304426075*^9, 3.647873046809783*^9}, 
   3.647876987698955*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"InitialFigure1", ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276617867672367`*^9, 3.627661879246334*^9}, {
  3.627661941781152*^9, 3.627661945291995*^9}, {3.6276621378577127`*^9, 
  3.627662143073347*^9}, {3.647873038748006*^9, 3.647873039039154*^9}, {
  3.6478730817879963`*^9, 3.647873082045033*^9}}],

Cell[TextData[{
 "Finally, we may combine the built-in functions ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Text",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Text.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Text.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " to label these points in a way that will be useful, not just for producing \
a nice static output picture, but also for producing animations where the \
labeling of a point can move with the point while the animation is occurring. \
 We have also included the option ",
 StyleBox[ButtonBox["AxesStyle",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/AxesStyle.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/AxesStyle.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and the graphics directive ",
 StyleBox[ButtonBox["Thick",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thick.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thick.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " to make the axes thicker."
}], "Text",
 CellChangeTimes->{{3.627663989023061*^9, 3.627664081159441*^9}, {
   3.627664191856192*^9, 3.627664216475559*^9}, {3.628875945121029*^9, 
   3.628875990285302*^9}, 3.630424789051283*^9, {3.6478730624608107`*^9, 
   3.647873107451933*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"InitialFigure1", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"4", ",", 
        RowBox[{"{", 
         RowBox[{"4.5", ",", ".5"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"4", "+", 
         RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"4.5", ",", "3.5"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"3", "\[ImaginaryI]"}], ",", 
        RowBox[{"{", 
         RowBox[{".5", ",", "3.5"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "7"}], "+", "\[ImaginaryI]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "7.3"}], ",", "1.5"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "-", 
         RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", 
          RowBox[{"-", "2.5"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"2", "-", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"2.5", ",", 
          RowBox[{"-", "1.5"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276617867672367`*^9, 3.627661879246334*^9}, {
  3.627661941781152*^9, 3.627661945291995*^9}, {3.6276621378577127`*^9, 
  3.627662143073347*^9}, {3.627664106625504*^9, 3.627664175947159*^9}, {
  3.6276642464009123`*^9, 3.627664332907702*^9}, {3.628875850707377*^9, 
  3.628875887398748*^9}, {3.62887592620961*^9, 3.628875929241864*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" Exercise 2:",
  FontWeight->"Bold"],
 "  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot, in the complex plane, of the points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "-", 
    RowBox[{"3", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "5"}], "+", 
    RowBox[{"8", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "4"}], "\[ImaginaryI]"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["10", TraditionalForm]]],
 ".  Make sure your axes are labeled appropriately, your window is chosen \
well, your points are larger than the default (and make them colored ",
 StyleBox[ButtonBox["Red",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Red.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Red.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 "), the grid-lines are included, the scales on the axes are the same, the \
axes are thick, and the points are labeled. Experiment with your code to \
strive to make it as efficient as possible (that is, as short as possible \
\[LongDash] and possibly use just one ",
 StyleBox[ButtonBox["cell",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/tutorial/WorkingWithCells.\
html"], None},
  ButtonNote->
   "http://reference.wolfram.com/language/tutorial/WorkingWithCells.html"],
  FontColor->RGBColor[1, 0.5, 0]],
 " of code rather than multiple cells).  Note that a semicolon \
\[OpenCurlyDoubleQuote];\[CloseCurlyDoubleQuote] will suppress output in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " but can also be used to separate distinct lines of code within the same \
cell if you wish."
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
   3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
   3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
   3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
   3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
   3.627657492593141*^9, 3.6276575163946*^9}, {3.627659108756077*^9, 
   3.627659190362417*^9}, {3.627662239262556*^9, 3.6276624566615953`*^9}, {
   3.6276624914328527`*^9, 3.627662499510579*^9}, {3.627664347055848*^9, 
   3.627664356094934*^9}, {3.627909630592648*^9, 3.627909643219245*^9}, {
   3.62790969635893*^9, 3.627909739165676*^9}, {3.6279097708285637`*^9, 
   3.627909788142371*^9}, {3.628876008395164*^9, 3.628876060054185*^9}, {
   3.647873166593781*^9, 3.647873166600049*^9}, 3.647877045776937*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Work 2: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
   3.627659434447322*^9, 3.627659440180417*^9}, {3.627659519063675*^9, 
   3.6276595191998262`*^9}, 3.627662240565363*^9}],

Cell[TextData[{
 StyleBox["(Enter your code under this cell when ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox[" is in \[OpenCurlyDoubleQuote]Input mode\[CloseCurlyDoubleQuote] \
\[LongDash] make sure a horizontal line is showing before you start typing)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]]
}], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659460201036*^9, 3.627659504551834*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Grader/Instructor ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Assessment 2: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
   3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
   3.62765955845679*^9}, {3.627659617632988*^9, 3.627659649751532*^9}, 
   3.6276622421979313`*^9}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell["\<\
In Activity 2 of this learning module on complex number addition and the \
complex plane, we will consider the geometric importance of this view for \
complex number addition.\
\>", "Text",
 CellChangeTimes->{{3.6478765286404448`*^9, 3.647876597620336*^9}, 
   3.647877562470521*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1212, 673},
WindowMargins->{{13, Automatic}, {51, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 645, 14, 183, "Title"],
Cell[CellGroupData[{
Cell[2156, 53, 255, 3, 78, "Subchapter"],
Cell[2414, 58, 3098, 74, 266, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5549, 137, 281, 4, 78, "Subchapter"],
Cell[5833, 143, 682, 14, 175, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6552, 162, 305, 4, 78, "Subchapter"],
Cell[6860, 168, 5478, 130, 227, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12375, 303, 250, 3, 188, "Subchapter"],
Cell[12628, 308, 1368, 28, 321, "Text"],
Cell[13999, 338, 3220, 70, 596, "Text"],
Cell[CellGroupData[{
Cell[17244, 412, 3634, 87, 781, "Subsection"],
Cell[CellGroupData[{
Cell[20903, 503, 152, 2, 127, "Subsubsection"],
Cell[21058, 507, 327, 6, 110, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21422, 518, 263, 3, 127, "Subsubsection"],
Cell[21688, 523, 420, 7, 110, "Text"],
Cell[22111, 532, 1078, 16, 331, "Text"],
Cell[23192, 550, 2250, 57, 257, "Text"],
Cell[25445, 609, 205, 6, 188, "Input"],
Cell[25653, 617, 295, 8, 188, "Input"],
Cell[25951, 627, 329, 10, 108, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26329, 643, 1437, 36, 445, "Subsection"],
Cell[CellGroupData[{
Cell[27791, 683, 264, 7, 127, "Subsubsection"],
Cell[28058, 692, 502, 12, 183, "Text"],
Cell[28563, 706, 327, 6, 110, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28927, 717, 336, 8, 127, "Subsubsection"],
Cell[29266, 727, 420, 7, 110, "Text"],
Cell[29689, 736, 1754, 38, 335, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31492, 780, 3967, 115, 1183, "Subsection"],
Cell[CellGroupData[{
Cell[35484, 899, 154, 2, 127, "Subsubsection"],
Cell[35641, 903, 352, 6, 110, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36030, 914, 312, 4, 127, "Subsubsection"],
Cell[36345, 920, 420, 7, 110, "Text"],
Cell[36768, 929, 1086, 27, 183, "Text"],
Cell[37857, 958, 299, 9, 108, "Input"],
Cell[38159, 969, 354, 10, 108, "Input"],
Cell[38516, 981, 648, 19, 183, "Text"],
Cell[39167, 1002, 307, 9, 108, "Input"],
Cell[39477, 1013, 550, 12, 183, "Text"],
Cell[40030, 1027, 896, 31, 171, "Input"],
Cell[40929, 1060, 5885, 152, 908, "Text"],
Cell[46817, 1214, 5897, 158, 620, "Text"],
Cell[52717, 1374, 1496, 43, 171, "Input"],
Cell[54216, 1419, 401, 11, 110, "Text"],
Cell[54620, 1432, 207, 3, 108, "Input"],
Cell[54830, 1437, 758, 18, 183, "Text"],
Cell[55591, 1457, 1513, 32, 183, "Text"],
Cell[57107, 1491, 1112, 28, 235, "Input"],
Cell[58222, 1521, 1620, 45, 257, "Text"],
Cell[59845, 1568, 227, 6, 102, "Input"],
Cell[60075, 1576, 433, 13, 110, "Text"],
Cell[60511, 1591, 302, 8, 102, "Input"],
Cell[60816, 1601, 617, 21, 183, "Text"],
Cell[61436, 1624, 579, 12, 110, "Text"],
Cell[62018, 1638, 326, 10, 102, "Input"],
Cell[62347, 1650, 155, 2, 110, "Text"],
Cell[62505, 1654, 393, 11, 102, "Input"],
Cell[62901, 1667, 482, 9, 183, "Text"],
Cell[63386, 1678, 823, 20, 108, "Input"],
Cell[64212, 1700, 1835, 41, 257, "Text"],
Cell[66050, 1743, 2289, 63, 297, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68388, 1812, 2940, 72, 722, "Subsection"],
Cell[CellGroupData[{
Cell[71353, 1888, 288, 7, 127, "Subsubsection"],
Cell[71644, 1897, 573, 14, 183, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72254, 1916, 366, 9, 127, "Subsubsection"],
Cell[72623, 1927, 420, 7, 110, "Text"],
Cell[73046, 1936, 293, 6, 183, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 3uppdXyfxT4cQCgEVS6yxTxv *)
