(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    101118,       2781]
NotebookOptionsPosition[     98688,       2687]
NotebookOutlinePosition[     99079,       2704]
CellTagsIndexPosition[     99036,       2701]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Complex Number Addition and the Complex (",
 StyleBox[ButtonBox["Argand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ArgandDiagram.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ArgandDiagram.html"],
  FontColor->RGBColor[0, 0, 1]],
 ") Plane, Activity 2"
}], "Title",
 CellChangeTimes->{
  3.6279099761990013`*^9, {3.628007103032901*^9, 3.628007104075787*^9}}],

Cell[CellGroupData[{

Cell["Learning Goals:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}}],

Cell[TextData[{
 "1) See that it is natural to view complex numbers as ",
 StyleBox[ButtonBox["vectors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Displacement_(vector)"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Displacement_(vector)"],
  FontColor->RGBColor[0, 0, 1]],
 " well as points, and that this interpretation leads to a geometric view of \
complex number addition in terms of the ",
 StyleBox[ButtonBox["parallelogram law",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ParallelogramLaw.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ParallelogramLaw.html"],
  FontColor->RGBColor[0, 0, 1]],
 " for vector addition.\n\t\n2) Learn basic applications of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Arrow",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Arrow.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Arrow.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Point",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Point.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Point.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and ",
 StyleBox[ButtonBox["Show",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Show.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Show.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " in this setting, as well as various ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " formatting options."
}], "Subsection",
 CellChangeTimes->{{3.629471283194976*^9, 3.629471449316176*^9}, {
  3.629471491689554*^9, 3.629471495629924*^9}, {3.629471555324888*^9, 
  3.629471755003772*^9}, {3.629471798155019*^9, 3.629471799321672*^9}, {
  3.629471860730651*^9, 3.629471867303534*^9}, {3.630416497210616*^9, 
  3.630416506292301*^9}, {3.64787632382583*^9, 3.6478763508471413`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prerequisites:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
   3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
   3.629471286589877*^9}, {3.62947861284763*^9, 3.629478616140943*^9}, 
   3.647877072998394*^9}],

Cell[TextData[{
 "1) Familiarity with vectors:  in physics, linear algebra, multivariable \
calculus, and/or differential equations\n\n2) ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " content from \[OpenCurlyDoubleQuote]Complex Number Addition and the \
Complex (",
 StyleBox[ButtonBox["Argand",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ArgandDiagram.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ArgandDiagram.html"],
  FontColor->RGBColor[0, 0, 1]],
 ") Plane, Activity 1\[CloseCurlyDoubleQuote]"
}], "Subsection",
 CellChangeTimes->{{3.629471283194976*^9, 3.629471449316176*^9}, {
   3.629471491689554*^9, 3.629471495629924*^9}, 3.629471704802578*^9, {
   3.6294717887322683`*^9, 3.629471791315475*^9}, 3.629471883527823*^9, {
   3.629478639313504*^9, 3.629478679493908*^9}, {3.629478720658692*^9, 
   3.629478816037221*^9}, {3.629478847617557*^9, 3.629478917607266*^9}, {
   3.647876407815935*^9, 3.6478764164118443`*^9}, 3.647953692142353*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction: ", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}, {3.6294714662738123`*^9, 3.629471468263523*^9}, {
  3.630073613440137*^9, 3.630073624429462*^9}}],

Cell[TextData[{
 StyleBox[ButtonBox["Vector quantities",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.grc.nasa.gov/WWW/k-12/airplane/vectors.html"], None},
  ButtonNote->"http://www.grc.nasa.gov/WWW/k-12/airplane/vectors.html"],
  FontColor->RGBColor[0, 0, 1]],
 " are very important in many applications of mathematics, the most prominent \
of which is physics, though vectors can come up in many other situations, ",
 StyleBox[ButtonBox["such as in economics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://books.google.com/books?id=3TSIkkDkFn4C&pg=PA1&lpg=PA1&dq=\
application+of+vectors+to+economics&source=bl&ots=PfQUjAvDzT&sig=\
ETZ3CK2o33hN5GJK_0x3u2XJSkI&hl=en&sa=X&ei=VFK5VIOyNpG0sASKrYB4&ved=\
0CGAQ6AEwCQ#v=onepage&q=application%20of%20vectors%20to%20"], None},
  ButtonNote->
   "https://books.google.com/books?id=3TSIkkDkFn4C&pg=PA1&lpg=PA1&dq=\
application+of+vectors+to+economics&source=bl&ots=PfQUjAvDzT&sig=\
ETZ3CK2o33hN5GJK_0x3u2XJSkI&hl=en&sa=X&ei=VFK5VIOyNpG0sASKrYB4&ved=\
0CGAQ6AEwCQ#v=onepage&q=application%20of%20vectors%20to%20"],
  FontColor->RGBColor[0, 0, 1]],
 ", where there is more than one variable to think about and work with.  \
Complex numbers can be viewed as two-dimensional vectors, and this view \
provides our first insights into the importance of the geometric \
interpretation of complex arithmetic.  To be more specific, we will learn \
that complex number addition can be seen to follow the geometric ",
 StyleBox[ButtonBox["parallelogram law",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ParallelogramLaw.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ParallelogramLaw.html"],
  FontColor->RGBColor[0, 0, 1]],
 " for the sum of two vectors and its \[OpenCurlyDoubleQuote]head-to-tail\
\[CloseCurlyDoubleQuote] ",
 StyleBox[ButtonBox["generalizations",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.physicsclassroom.com/class/vectors/Lesson-1/Vector-\
Addition"], None},
  ButtonNote->
   "http://www.physicsclassroom.com/class/vectors/Lesson-1/Vector-Addition"],
  FontColor->RGBColor[0, 0, 1]],
 " to the ",
 StyleBox[ButtonBox["sum of more than two vectors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.virtualnerd.com/intro-physics/vectors/addition-\
subtraction/add-subtract-multiple-vectors/add-head-tail-three-vector"], None},
  
  ButtonNote->
   "http://www.virtualnerd.com/intro-physics/vectors/addition-subtraction/add-\
subtract-multiple-vectors/add-head-tail-three-vector"],
  FontColor->RGBColor[0, 0, 1]],
 ".  We will eventually see that this allows us to understand ",
 StyleBox[ButtonBox["complex-valued functions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Complex-valued_function"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Complex-valued_function"],
  FontColor->RGBColor[0, 0, 1]],
 ", ",
 StyleBox[ButtonBox["such as",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframalpha.com/input/?i=e%5E%28i+theta%29"], None},
  ButtonNote->"http://www.wolframalpha.com/input/?i=e%5E%28i+theta%29"],
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{" ", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]], TraditionalForm]]],
 ", more deeply. "
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/e37W6NKnteOBz9xRILoR0waiSD6//4dYLrCSCsL
RP9yhdBW1p+LQHSV+LoqEL0kT7wRREeELmoC0Wf3dLSB6BvPq/tBdJdB2i4Q
/eqG9A0QfSF+/V0QfbcSQiup2T0C0XvNQ56CaMk1IS9B9IEm5l8g+o1dFXsV
kD4TZ8wFov8E7FAH0dN+NWuC6ObzakZg+aKtDiDa4/A1PxD96q1MOIhe+u1L
NIhewPMVTPPWKieC6CseL8H0vOPpaSB6u+vhHBD9o+dnAYhWXwyh86K7Th3V
fe24tar4NIgGAGeelAY=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Content:", "Subchapter",
 CellChangeTimes->{{3.6294708824182262`*^9, 3.6294708852158613`*^9}, {
  3.6294709184784937`*^9, 3.6294711641254807`*^9}, {3.629471214221171*^9, 
  3.629471286589877*^9}, {3.6294714662738123`*^9, 3.629471468263523*^9}}],

Cell[TextData[{
 "In introductory physics classes, a ",
 StyleBox[ButtonBox["vector",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Euclidean_vector"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Euclidean_vector"],
  FontColor->RGBColor[0, 0, 1]],
 " is a typically described as a quantity that has both a magnitude (\
\[OpenCurlyDoubleQuote]size\[CloseCurlyDoubleQuote]) and a direction \
associated with it. When you push a table horizontally across a floor at a \
constant speed in one direction, you are applying a constant force to the \
table that has a magnitude and a direction \[LongDash] the magnitude is \
related to how hard you are pushing.  When the speed is constant, the floor, \
through friction, is also applying an opposing force to the table whose \
magnitude is the same as the magnitude of the force you are applying, but \
whose direction is exactly opposite yours.  "
}], "Text",
 CellChangeTimes->{{3.62791011883221*^9, 3.627910223533432*^9}, {
  3.627910453311989*^9, 3.627910691153723*^9}, {3.627910739606596*^9, 
  3.627910750491465*^9}, {3.627911505741619*^9, 3.627911505744442*^9}, {
  3.628005175149878*^9, 3.628005229886798*^9}, {3.628876126949891*^9, 
  3.628876143711053*^9}, {3.628876178454625*^9, 3.6288762079553127`*^9}}],

Cell["\<\
An arrow is a natural way to visually represent a vector, since a given arrow \
has a certain magnitude \
(\[OpenCurlyDoubleQuote]length\[CloseCurlyDoubleQuote]) and a certain \
direction.  We are also free to visualize the arrow to be based (started) \
with it\[CloseCurlyQuote]s \
\[OpenCurlyDoubleQuote]tail\[CloseCurlyDoubleQuote] at any point we want.  In \
other words, the location of the arrow does not change the vector it \
represents. We are free to rigidly translate the arrow wherever we want.  \
However, when using vectors to analyze physical models, the choice of \
location of the base of the arrow can help or hinder problem-solving as well \
as understanding the physical meaning of the quantities involved.\
\>", "Text",
 CellChangeTimes->{{3.6279107701335506`*^9, 3.627910947950622*^9}, {
   3.627911045510475*^9, 3.6279110770217323`*^9}, {3.628005322599574*^9, 
   3.6280055187527733`*^9}, 3.647876831430373*^9, {3.6478768846519136`*^9, 
   3.647876929050397*^9}, {3.647877422516469*^9, 3.6478774333050213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Discussion 1:",
  FontWeight->"Bold"],
 "  Whether you\[CloseCurlyQuote]ve had physics or not, discuss and then \
describe other physical quantities/measurements that would be vectors, having \
both a magnitude and a direction.  Also discuss and then describe the most \
beneficial spot to place the base of the vectors when drawn as arrows in \
diagrams, depending on the physical quantities or measurements they \
represent.  As a hint to get you started, think about vectors that would help \
to describe the motion of a car around a parking lot, not just in terms of \
its position, but also in terms of what the driver sees through the front \
window and on the speedometer as time goes by."
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
  3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
  3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
  3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
  3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
  3.627657492593141*^9, 3.6276575163946*^9}, {3.627659369469182*^9, 
  3.627659372254017*^9}, {3.6279081214851007`*^9, 3.627908138201469*^9}, {
  3.627908171701682*^9, 3.6279082835834637`*^9}, {3.627908355561986*^9, 
  3.627908496036009*^9}, {3.62790879589528*^9, 3.627908795898261*^9}, {
  3.627911181039608*^9, 3.627911322047985*^9}, {3.627911431654087*^9, 
  3.6279114396005917`*^9}, {3.628005539934293*^9, 3.628005573485806*^9}, {
  3.628876309826745*^9, 3.628876313399467*^9}, {3.647877475034204*^9, 
  3.647877538373098*^9}}],

Cell[CellGroupData[{

Cell["Response 1: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grader/Instructor Response 1: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.62765961929755*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "Given a complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", we saw in Activity 1 that it can be associated with a point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " graphed in a standard ",
 StyleBox[ButtonBox["rectangular coordinate system",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Cartesian_coordinate_system"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Cartesian_coordinate_system"],
  FontColor->RGBColor[0, 0, 1]],
 " over a plane.  It is natural to then draw an arrow based at the origin ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " and having a tip or \[OpenCurlyDoubleQuote]head\[CloseCurlyDoubleQuote] \
(terminal point) at the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]]],
 " in this plane.  Because of this natural correspondence, we can think of \
the arrow itself as being yet another way to geometrically interpret the \
complex number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ".  In other words, we can think of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " as literally being a vector, the vector with the given magnitude (\
\[OpenCurlyDoubleQuote]length\[CloseCurlyDoubleQuote]) and direction that we \
have just drawn."
}], "Text",
 CellChangeTimes->{{3.6279115455053587`*^9, 3.627911631770093*^9}, {
  3.627911678185623*^9, 3.62791167818779*^9}, {3.6279117645895157`*^9, 
  3.627911916702344*^9}, {3.627913146198986*^9, 3.627913171051347*^9}, {
  3.628005583252339*^9, 3.6280056247462187`*^9}, {3.62800566561415*^9, 
  3.628005667417716*^9}, {3.62800716292312*^9, 3.628007164357918*^9}, {
  3.628876329161037*^9, 3.628876330419393*^9}, {3.647877590589396*^9, 
  3.647877591722166*^9}}],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the most basic way to draw a vector is through the combined use of ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Arrow",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Arrow.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Arrow.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", as illustrated in the following line of code."
}], "Text",
 CellChangeTimes->{{3.627913204776683*^9, 3.627913230438877*^9}, {
   3.627913273170944*^9, 3.627913293213957*^9}, {3.6279133702384653`*^9, 
   3.6279133711635647`*^9}, {3.627916129367601*^9, 3.62791613037134*^9}, 
   3.630421111910212*^9}],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"Arrow", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6279133043455153`*^9, 3.627913317068246*^9}}],

Cell[TextData[{
 "The lists ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}], TraditionalForm]]],
 " represent the base point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 " and terminal point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "3"}], ")"}], TraditionalForm]]],
 " of the vector.  The given vector can be visualized, via change in base \
point, in infinitely many ways; though the most natural way, absent any \
physical applications, is to start it at the origin.  The following code \
therefore produces two copies of the same vector, with the lower one being \
the one that is based at the origin."
}], "Text",
 CellChangeTimes->{{3.6279133235481567`*^9, 3.6279135493330517`*^9}, 
   3.6478770860161753`*^9, {3.647877647063735*^9, 3.647877657751302*^9}}],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "3"}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6279135243018303`*^9, 3.627913539789867*^9}}],

Cell[TextData[{
 "We can see this within a wider window in the given coordinate system by \
using the options ",
 StyleBox[ButtonBox["Axes",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Axes.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Axes.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["AxesStyle",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/AxesStyle.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/AxesStyle.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ",  ",
 StyleBox[ButtonBox["GridLines",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/GridLines.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/GridLines.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/PlotRange.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/PlotRange.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ".  We can also color and thicken the arrows with and ",
 StyleBox[ButtonBox["Thick",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thick.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thick.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Red",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Red.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Red.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 "."
}], "Text",
 CellChangeTimes->{{3.627913557918687*^9, 3.6279135823982773`*^9}, {
  3.6279136548397837`*^9, 3.62791365932581*^9}, {3.627913732665962*^9, 
  3.627913960399766*^9}, {3.6279145945141363`*^9, 3.6279146072834377`*^9}}],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Thick", ",", "Red", ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "3"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "5"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6279135243018303`*^9, 3.627913539789867*^9}, {
  3.62791366133953*^9, 3.6279137753746223`*^9}, {3.627914091276505*^9, 
  3.6279140938395147`*^9}, {3.627914585403901*^9, 3.627914587988428*^9}}],

Cell[TextData[{
 "We can now graph the same diagram as in Activity 1, but with the natural \
origin-based vectors for each complex number shown as well, allowing us to \
match ",
 StyleBox[ButtonBox["Figure [1] (Ch. 1.I .1, p. 2) of Tristan Needham\
\[CloseCurlyQuote]s Visual Complex Analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?s=books&ie=UTF8&qid=1419886831&sr=1-1&keywords=visual+\
complex+analysis"], None},
  ButtonNote->
   "http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?s=books&ie=UTF8&qid=1419886831&sr=1-1&keywords=visual+\
complex+analysis"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0.5, 0, 0.5]],
 " more fully.  The user-defined variable ",
 StyleBox["Points",
  FontWeight->"Bold"],
 " is being used to store a list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}], TraditionalForm]]],
 " of the points being plotted with ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ".  The expression ",
 StyleBox["Points",
  FontWeight->"Bold"],
 "[[k]], which uses the ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Part.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " ",
 StyleBox[ButtonBox["[[ ]]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Part.html"],
  FontColor->RGBColor[1, 0.5, 0]],
 " operator, then represents the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["k", "th"], TraditionalForm]]],
 " element of the list ",
 StyleBox["Points",
  FontWeight->"Bold"],
 " \[LongDash] for instance, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["Points",
      FontWeight->"Bold"], "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7"}], ",", "1"}], "}"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.627914161625793*^9, 3.627914267624559*^9}, {
   3.627914361974869*^9, 3.6279144151107817`*^9}, {3.627914447991742*^9, 
   3.627914505609367*^9}, {3.6280057239114923`*^9, 3.6280057247799397`*^9}, {
   3.6280071692670307`*^9, 3.628007170189168*^9}, {3.628876428678591*^9, 
   3.628876448044072*^9}, 3.6304209727790213`*^9, {3.630421274250288*^9, 
   3.6304213322940598`*^9}, {3.647877711177806*^9, 3.647877712677174*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{"InitialFigure1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Points", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<real\>\"", ",", "\"\<imaginary\>\""}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"InitialFigure1", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", ".5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"4", "+", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"3", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{".5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "7"}], "+", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "7.3"}], ",", "1.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "-", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.5"}], ",", 
           RowBox[{"-", "2.5"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"2", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", 
           RowBox[{"-", "1.5"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Red", ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"Points", "[", 
           RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6276610889420233`*^9, 3.6276611061661463`*^9}, {
  3.6276611940880632`*^9, 3.627661260925015*^9}, {3.6276613034521437`*^9, 
  3.627661317608073*^9}, {3.6276613793788347`*^9, 3.6276614154510317`*^9}, {
  3.627661554097768*^9, 3.627661556202138*^9}, {3.627661590985866*^9, 
  3.627661591738063*^9}, {3.627914284994396*^9, 3.62791435106917*^9}, {
  3.62791457220428*^9, 3.627914575064103*^9}, {3.6279146132952414`*^9, 
  3.6279146868562717`*^9}, {3.627914965318413*^9, 3.6279149696139307`*^9}, {
  3.627916012481439*^9, 3.627916013469536*^9}, {3.62800574276161*^9, 
  3.6280057464963417`*^9}}],

Cell[TextData[{
 "A slightly more efficient way to create the last picture is to make use of ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Length",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Length.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Length.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", the last of which returns the number of elements of a list \[LongDash] in \
this case, the elements are themselves lists with two elements.  Recall from \
Activity 1 that ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Table.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Table.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " creates lists of objects in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that have \[OpenCurlyDoubleQuote]formulas\[CloseCurlyDoubleQuote]. In this \
case, the formula is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"Points", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], 
   TraditionalForm]],
  FontWeight->"Bold"],
 ", which creates an arrow from the origin ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " to the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "th"], TraditionalForm]]],
 " entry of ",
 StyleBox["Points",
  FontWeight->"Bold"],
 ".  ",
 StyleBox[ButtonBox["Text",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Text.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Text.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Style",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Style.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Style.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", ",
 StyleBox[ButtonBox["Large",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Large.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Large.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and ",
 StyleBox[ButtonBox["Italic",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Italic.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Italic.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " have also been combined to make the labeling of the axes look nicer."
}], "Text",
 CellChangeTimes->{{3.6279147852665777`*^9, 3.627914867082799*^9}, {
   3.627914905501338*^9, 3.627914928116219*^9}, {3.62800578888938*^9, 
   3.628005861178547*^9}, {3.628005908197022*^9, 3.628005912548245*^9}, {
   3.628007174889903*^9, 3.6280071758610983`*^9}, {3.628876507646304*^9, 
   3.628876562761767*^9}, 3.6304210724083557`*^9, {3.647877911770111*^9, 
   3.647877923048539*^9}, {3.6478779770687103`*^9, 3.647878068783805*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{"InitialFigure1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Points", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], "]"}],
         ",", 
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
         "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"InitialFigure1", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", ".5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"4", "+", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"3", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{".5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "7"}], "+", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "7.3"}], ",", "1.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "-", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.5"}], ",", 
           RowBox[{"-", "2.5"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"2", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", 
           RowBox[{"-", "1.5"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Red", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"Points", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "Points", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6276610889420233`*^9, 3.6276611061661463`*^9}, {
   3.6276611940880632`*^9, 3.627661260925015*^9}, {3.6276613034521437`*^9, 
   3.627661317608073*^9}, {3.6276613793788347`*^9, 3.6276614154510317`*^9}, {
   3.627661554097768*^9, 3.627661556202138*^9}, {3.627661590985866*^9, 
   3.627661591738063*^9}, {3.627914284994396*^9, 3.62791435106917*^9}, {
   3.62791457220428*^9, 3.627914575064103*^9}, {3.6279146132952414`*^9, 
   3.6279146868562717`*^9}, {3.6279147486334467`*^9, 3.62791477877801*^9}, {
   3.627914811240212*^9, 3.627914813418067*^9}, 3.627914978240863*^9, {
   3.627915987138405*^9, 3.627915988308943*^9}, {3.628005768018014*^9, 
   3.6280057725603437`*^9}, {3.647877889385179*^9, 3.6478778959135017`*^9}, {
   3.647877928201086*^9, 3.647877962629086*^9}}],

Cell[TextData[{
 "Changing the ",
 StyleBox[ButtonBox["Thick",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thick.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thick.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " directive to ",
 StyleBox[ButtonBox["Thickness",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thickness.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thickness.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ", and giving a numerical input for ",
 StyleBox[ButtonBox["Thickness",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thickness.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thickness.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " (such as .01) that gives a fraction of the horizontal plot range (such as \
1%), allows us to make the vectors even thicker."
}], "Text",
 CellChangeTimes->{{3.647879301048015*^9, 3.647879444160058*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";", 
  RowBox[{"InitialFigure1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Points", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], "]"}],
         ",", 
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
         "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "9"}], ",", "9"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"i", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"InitialFigure1", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"4", ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", ".5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"4", "+", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"4.5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"3", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{".5", ",", "3.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "7"}], "+", "\[ImaginaryI]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "7.3"}], ",", "1.5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "-", 
          RowBox[{"3", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.5"}], ",", 
           RowBox[{"-", "2.5"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"2", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"2.5", ",", 
           RowBox[{"-", "1.5"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", ".01", "]"}], ",", "Red", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"Points", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "Points", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6276610889420233`*^9, 3.6276611061661463`*^9}, {
   3.6276611940880632`*^9, 3.627661260925015*^9}, {3.6276613034521437`*^9, 
   3.627661317608073*^9}, {3.6276613793788347`*^9, 3.6276614154510317`*^9}, {
   3.627661554097768*^9, 3.627661556202138*^9}, {3.627661590985866*^9, 
   3.627661591738063*^9}, {3.627914284994396*^9, 3.62791435106917*^9}, {
   3.62791457220428*^9, 3.627914575064103*^9}, {3.6279146132952414`*^9, 
   3.6279146868562717`*^9}, {3.6279147486334467`*^9, 3.62791477877801*^9}, {
   3.627914811240212*^9, 3.627914813418067*^9}, 3.627914978240863*^9, {
   3.627915987138405*^9, 3.627915988308943*^9}, {3.628005768018014*^9, 
   3.6280057725603437`*^9}, {3.647877889385179*^9, 3.6478778959135017`*^9}, {
   3.647877928201086*^9, 3.647877962629086*^9}, {3.647879458649746*^9, 
   3.647879460026682*^9}}],

Cell[TextData[{
 "In physics, when a vector is drawn from the origin to a given point, that \
vector is called the ",
 StyleBox[ButtonBox["position vector",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Position_%28vector%29"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Position_%28vector%29"],
  FontColor->RGBColor[0, 0, 1]],
 " of the given point (relative to the given coordinate system), though we \
could once again translate this vector to be based at any spot we want, and \
it would still be called the position vector of the given point."
}], "Text",
 CellChangeTimes->{{3.627915010615593*^9, 3.627915100871472*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" Exercise 1:",
  FontWeight->"Bold"],
 "  Use ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " to make a plot, in the complex plane, of the points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "-", 
    RowBox[{"3", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "5"}], "+", 
    RowBox[{"8", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "4"}], "\[ImaginaryI]"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["10", TraditionalForm]]],
 ".  Make sure your axes are labeled appropriately, your window is chosen \
well, your points are larger than the default (and make them colored ",
 StyleBox[ButtonBox["Blue",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Blue.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Blue.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 "), the grid-lines are included, the scales on the axes are the same, the \
axes are thick, and the points are labeled. ",
 StyleBox["Also",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " make use of ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Arrow",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Arrow.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Arrow.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " to make position vectors for these points (and make them colored ",
 StyleBox[ButtonBox["Green",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Green.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Green.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 "). Experiment with your code to strive to make it as efficient as possible \
(as short as possible, and possibly just use one ",
 StyleBox[ButtonBox["cell",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/tutorial/WorkingWithCells.\
html"], None},
  ButtonNote->
   "http://reference.wolfram.com/language/tutorial/WorkingWithCells.html"],
  FontColor->RGBColor[1, 0.5, 0]],
 " of code rather than multiple cells).  Note that a semicolon \
\[OpenCurlyDoubleQuote];\[CloseCurlyDoubleQuote] will suppress output in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " but can also be used to separate distinct lines of code within the same \
cell if you wish."
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
   3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
   3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
   3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
   3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
   3.627657492593141*^9, 3.6276575163946*^9}, {3.627659108756077*^9, 
   3.627659190362417*^9}, {3.627908677348465*^9, 3.6279087177368393`*^9}, {
   3.627915943542495*^9, 3.627915953032187*^9}, {3.62791602506989*^9, 
   3.627916047611404*^9}, {3.627916089879258*^9, 3.6279161105186167`*^9}, 
   3.6280059612857428`*^9, {3.6288766369927673`*^9, 3.628876662716511*^9}, {
   3.630420983839383*^9, 3.630421018472382*^9}, 3.6478770915452747`*^9, {
   3.647878119010542*^9, 3.647878137804841*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Work 1: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659434447322*^9, 3.627659440180417*^9}, {3.627659519063675*^9, 
  3.6276595191998262`*^9}}],

Cell[TextData[{
 StyleBox["(Enter your code under this cell when ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox[" is in \[OpenCurlyDoubleQuote]Input mode\[CloseCurlyDoubleQuote] \
\[LongDash] make sure a horizontal line is showing before you start typing)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]]
}], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659460201036*^9, 3.627659504551834*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Grader/Instructor ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Assessment 1: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.627659649751532*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "It can be experimentally verified that when two forces are applied to an \
object, the ",
 StyleBox[ButtonBox["resultant (\[OpenCurlyDoubleQuote]net\
\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]total\
\[CloseCurlyDoubleQuote]) force",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.physicsclassroom.com/class/vectors/Lesson-1/Resultants"], 
    None},
  ButtonNote->
   "http://www.physicsclassroom.com/class/vectors/Lesson-1/Resultants"],
  FontColor->RGBColor[0, 0, 1]],
 " can be determined by the so-called ",
 StyleBox[ButtonBox["parallelogram law",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ParallelogramLaw.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ParallelogramLaw.html"],
  FontColor->RGBColor[0, 0, 1]],
 ".  To be more specific, if two vectors ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " are not parallel \[LongDash] they are neither in the same nor the opposite \
direction \[LongDash] and neither is a \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["zero vector",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ZeroVector.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ZeroVector.html"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] (represented as a point rather than an arrow so \
that it has length zero and has no direction), then a parallelogram can be \
formed by first picking a common point ",
 StyleBox["P",
  FontSlant->"Italic"],
 " to use as the base for both ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 ", then drawing another copy of ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " at the tip of ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and another copy of ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " at the tip of ",
 StyleBox["v",
  FontWeight->"Bold"],
 ".  These last two vectors will meet at a common point ",
 StyleBox["Q",
  FontSlant->"Italic"],
 ".  If ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " represent forces acting on one object, then the arrow drawn from ",
 StyleBox["P",
  FontSlant->"Italic"],
 " to ",
 StyleBox["Q",
  FontSlant->"Italic"],
 " will represent the total force acting on the object, and it is natural and \
common to represent this force symbolically as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["v",
     FontWeight->"Bold",
     FontSlant->"Plain"], "+", 
    StyleBox["w",
     FontWeight->"Bold",
     FontSlant->"Plain"]}], TraditionalForm]]],
 ", implying that we are thinking of ",
 StyleBox[ButtonBox["the two individual forces \[OpenCurlyDoubleQuote]adding\
\[CloseCurlyDoubleQuote] to give the total force",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.physicsclassroom.com/class/vectors/Lesson-3/Addition-of-\
Forces"], None},
  ButtonNote->
   "http://www.physicsclassroom.com/class/vectors/Lesson-3/Addition-of-\
Forces"],
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.627916200923512*^9, 3.627916517896332*^9}, {
  3.627916548682979*^9, 3.627916566771597*^9}, {3.627916597643941*^9, 
  3.627916617975895*^9}, {3.6279166540204144`*^9, 3.62791665402311*^9}, {
  3.627916795772193*^9, 3.627917101003771*^9}, {3.6279171313888817`*^9, 
  3.627917259974334*^9}, {3.627917464885167*^9, 3.627917488328001*^9}, {
  3.628006300365521*^9, 3.628006303152787*^9}, {3.628876688091629*^9, 
  3.628876690887492*^9}}],

Cell["\<\
Entering the following line of code will help you visualize the ideas in the \
last paragraph.\
\>", "Text",
 CellChangeTimes->{{3.627917774422256*^9, 3.6279178086287603`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", ".01", "]"}], ",", "Red", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "5"}], "}"}]}], "}"}], "]"}], ",", "Blue", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "5"}], "}"}]}], "}"}], "]"}], ",", "Black", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "5"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<v\>\"", ",", "Large"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"1.3", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<v\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<w\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".4", ",", "2"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<w\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"2.7", ",", "3.2"}], "}"}]}], "]"}], ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<v+w\>\"", ",", "Large"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.3", ",", "2.5"}], "}"}]}], "]"}], ",", 
        RowBox[{"60", " ", "Degree"}]}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".1"}], ",", "5.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".1"}], ",", "5.1"}], "}"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.627917816394308*^9, 3.627918003831655*^9}, {
   3.62791954252813*^9, 3.627919575853554*^9}, {3.6280063495729227`*^9, 
   3.628006350042568*^9}, {3.6280063940641117`*^9, 3.62800654403437*^9}, {
   3.6280065742992973`*^9, 3.62800665220852*^9}, {3.628006751322123*^9, 
   3.62800680491823*^9}, 3.62800683889365*^9, {3.647879267828411*^9, 
   3.647879275969776*^9}, {3.6478795014568977`*^9, 3.647879513734939*^9}}],

Cell[TextData[{
 "Actually, half the diagram above is ",
 StyleBox[ButtonBox["superfluous",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.merriam-webster.com/dictionary/superfluous"], None},
  ButtonNote->"http://www.merriam-webster.com/dictionary/superfluous"],
  FontColor->RGBColor[0, 0, 1]],
 ", unless our goal is to do a (visual) \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["proof without words",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.amazon.com/Proofs-without-Words-Exercises-Classroom/dp/\
0883857006"], None},
  ButtonNote->
   "http://www.amazon.com/Proofs-without-Words-Exercises-Classroom/dp/\
0883857006"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote] of the ",
 StyleBox[ButtonBox["commutative property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathsisfun.com/associative-commutative-distributive.html"]\
, None},
  ButtonNote->
   "http://www.mathsisfun.com/associative-commutative-distributive.html"],
  FontColor->RGBColor[0, 0, 1]],
 " for vectors.  All we need to focus on is the fact that we can first draw \
one copy of ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and then draw one copy of ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 ", based at the tip of ",
 StyleBox["v",
  FontWeight->"Bold"],
 ", and we will be able to draw ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["v",
     FontWeight->"Bold",
     FontSlant->"Plain"], "+", 
    StyleBox["w",
     FontWeight->"Bold",
     FontSlant->"Plain"]}], TraditionalForm]]],
 " correctly.  Such a process can be more easily extended to the sum of more \
than two vectors \[LongDash] we just keep placing the vectors \
\[OpenCurlyDoubleQuote]tip to tail\[CloseCurlyDoubleQuote] (put the base \
(tail) of the next vector at the tip of the preceding one).  This is \
illustrated with the code below."
}], "Text",
 CellChangeTimes->{{3.627918441274136*^9, 3.627918452016561*^9}, {
  3.627918483884882*^9, 3.6279185761168203`*^9}, {3.6279186564210377`*^9, 
  3.627918656489205*^9}, {3.627918873485746*^9, 3.627918873488356*^9}, {
  3.627918910295895*^9, 3.6279189104278097`*^9}, {3.627918970130666*^9, 
  3.627919055381526*^9}, {3.627919310250334*^9, 3.627919373612996*^9}, {
  3.627919514573574*^9, 3.627919521872847*^9}, {3.628006686891926*^9, 
  3.628006707569847*^9}, {3.647879563190551*^9, 3.647879564010881*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", ".01", "]"}], ",", "Red", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}]}], "}"}], "]"}], ",", "Blue", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "5"}], "}"}]}], "}"}], "]"}], ",", "Green", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"3", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "2"}], "}"}]}], "}"}], "]"}], ",", "Black", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "2"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<u\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".4", ",", "2"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<v\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4.3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<w\>\"", ",", "Large"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"3.7", ",", "3.7"}], "}"}]}], "]"}], ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<u+v+w\>\"", ",", "Large"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1.3"}], "}"}]}], "]"}], ",", 
        RowBox[{"27", "Degree"}]}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".1"}], ",", "5.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".1"}], ",", "5.1"}], "}"}]}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.627917816394308*^9, 3.627918003831655*^9}, {
  3.627919385356543*^9, 3.627919507154645*^9}, {3.628006858951009*^9, 
  3.628007024895712*^9}, {3.647879575964267*^9, 3.647879577749876*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Discussion 2:",
  FontWeight->"Bold"],
 " Does this way of interpreting vector addition make sense in other \
contexts?  For instance, what if you travel from a point ",
 StyleBox["P",
  FontSlant->"Italic"],
 " to a point ",
 StyleBox["Q",
  FontSlant->"Italic"],
 " and then to a point ",
 StyleBox["R ",
  FontSlant->"Italic"],
 "and then let ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " represent the corresponding \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["displacement vectors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Displacement_%28vector%29"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Displacement_%28vector%29"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote]?  What about if you are swimming at a nonzero \
angle with the straight current of a straight river, where ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " represents your constant velocity relative to the river and ",
 StyleBox["w",
  FontWeight->"Bold"],
 " represents the constant velocity of the current relative to the river \
banks?  "
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
   3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
   3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
   3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
   3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
   3.627657492593141*^9, 3.6276575163946*^9}, {3.627659369469182*^9, 
   3.627659372254017*^9}, {3.6279081214851007`*^9, 3.627908138201469*^9}, {
   3.627908171701682*^9, 3.6279082835834637`*^9}, {3.627908355561986*^9, 
   3.627908496036009*^9}, {3.62790879589528*^9, 3.627908795898261*^9}, {
   3.627911181039608*^9, 3.627911322047985*^9}, {3.627911431654087*^9, 
   3.6279114396005917`*^9}, {3.627917564709262*^9, 3.627917755933461*^9}, {
   3.627918051868848*^9, 3.6279182790241823`*^9}, 3.628876788845209*^9, {
   3.647879611875235*^9, 3.6478796136004353`*^9}}],

Cell[CellGroupData[{

Cell["Response 2: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.6279187218660517`*^9, 
  3.627918721940529*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Grader/Instructor Response 2: ", "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.62765961929755*^9}, {
  3.627918723972048*^9, 3.627918724022256*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "We saw in the Activity 1 that it makes symbolic sense to add complex \
numbers as if they were linear polynomials in the indeterminate \
\[ImaginaryI].  That is, it seems that defining ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"b", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"d", " ", "\[ImaginaryI]"}]}], ")"}]}], TraditionalForm]]],
 " to be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "c"}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "+", "d"}], ")"}], "\[ImaginaryI]"}]}], 
   TraditionalForm]]],
 " might be a good idea.  Indeed, algebraically-speaking, this is part of \
what is necessary to make the set of all complex numbers \
\[DoubleStruckCapitalC] into an ",
 StyleBox[ButtonBox["algebraic structure",
  BaseStyle->"Hyperlink",
  ButtonData->{"v", None}],
  FontColor->RGBColor[0, 0, 1]],
 " called a ",
 StyleBox[ButtonBox["field",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Field_(mathematics)"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Field_(mathematics)"],
  FontColor->RGBColor[0, 0, 1]],
 " (",
 StyleBox["not",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " to be confused with a ",
 StyleBox[ButtonBox["vector field",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Vector_field"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Vector_field"],
  FontColor->RGBColor[0, 0, 1]],
 ").  The other necessary part to make \[DoubleStruckCapitalC] a field is to \
define multiplication in a \
\[OpenCurlyDoubleQuote]good\[CloseCurlyDoubleQuote] way.  What does all this \
mean?  In a nutshell, with respect to addition, the collection of all complex \
numbers satisfies every algebraic property you could hope for:  ",
 StyleBox[ButtonBox["associativity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathwarehouse.com/dictionary/A-words/definition-of-\
associative-property.php"], None},
  ButtonNote->
   "http://www.mathwarehouse.com/dictionary/A-words/definition-of-associative-\
property.php"],
  FontColor->RGBColor[0, 0, 1]],
 ", ",
 StyleBox[ButtonBox["commutativity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathwarehouse.com/dictionary/C-words/commutative-property.\
php"], None},
  ButtonNote->
   "http://www.mathwarehouse.com/dictionary/C-words/commutative-property.php"],
  FontColor->RGBColor[0, 0, 1]],
 ", existence of an ",
 StyleBox[ButtonBox["additive identity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Additive_identity"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Additive_identity"],
  FontColor->RGBColor[0, 0, 1]],
 " (the number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "=", 
    RowBox[{"0", "+", 
     RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], TraditionalForm]]],
 ") and existence of ",
 StyleBox[ButtonBox["additive inverses",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Additive_inverse"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Additive_inverse"],
  FontColor->RGBColor[0, 0, 1]],
 " \[LongDash] the additive inverse of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "a"}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "b"}], ")"}], "\[ImaginaryI]"}]}], TraditionalForm]]],
 ".  Once multiplication has been defined, similar properties will hold for \
it, as well as the ",
 StyleBox[ButtonBox["distributive property",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Distributive_property"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Distributive_property"],
  FontColor->RGBColor[0, 0, 1]],
 ", which relates multiplication and addition.  The number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "=", 
    RowBox[{"1", "+", 
     RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " will be the ",
 StyleBox[ButtonBox["multiplicative identity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/1_(number)"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/1_(number)"],
  FontColor->RGBColor[0, 0, 1]],
 " and it will also turn out that nonzero complex numbers will have \
multiplicative inverses (at the moment, we\[CloseCurlyQuote]ll leave it to \
you to figure out what the ",
 StyleBox[ButtonBox["multiplicative inverse",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Multiplicative_inverse"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Multiplicative_inverse"],
  FontColor->RGBColor[0, 0, 1]],
 " (reciprocal) of a nonzero number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " will be, if you wish)."
}], "Text",
 CellChangeTimes->{{3.6280071912716093`*^9, 3.628007299753134*^9}, {
  3.628007354281349*^9, 3.628007367346219*^9}, {3.628007407844302*^9, 
  3.628007407847151*^9}, {3.628007446639553*^9, 3.6280076827574883`*^9}, {
  3.62801356187967*^9, 3.628013585133748*^9}, {3.6280136220839252`*^9, 
  3.6280136947301903`*^9}, {3.628013816376335*^9, 3.628013816379263*^9}, {
  3.6280138581331663`*^9, 3.628013858137542*^9}, {3.628013939863043*^9, 
  3.628013939866047*^9}, {3.628013972008925*^9, 3.6280139720129213`*^9}, {
  3.628014030659895*^9, 3.628014030662787*^9}, {3.628876820023786*^9, 
  3.628876823674608*^9}, {3.647879671241399*^9, 3.647879680006049*^9}, {
  3.6478797259907227`*^9, 3.64787992678592*^9}, {3.647880012097993*^9, 
  3.6478800146154737`*^9}}],

Cell[TextData[{
 "To more fully justify this definition of addition of complex numbers as a \
good idea, we need to explore what it means geometrically.  Let\
\[CloseCurlyQuote]s consider a particular example:  the fact that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"4", "+", "\[ImaginaryI]"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "4"}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", "1"}], ")"}], "\[ImaginaryI]"}]}], "=", 
     RowBox[{"5", "+", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}]}], TraditionalForm]]],
 ".  If we visualize these complex numbers as points in the complex plane, we \
get the picture generated by the following code.  For variety and to \
illustrate ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s flexibility, we note that we are now making these \
points by combining ",
 StyleBox[ButtonBox["Graphics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Graphics.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Graphics.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and ",
 StyleBox[ButtonBox["Point",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Point.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Point.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " rather than using ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/ListPlot.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 ".  Note also the use of ",
 StyleBox[ButtonBox["PointSize",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/PointSize.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/PointSize.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " and how it behaves in a way similar to ",
 StyleBox[ButtonBox["Thickness",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Thickness.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Thickness.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 "."
}], "Text",
 CellChangeTimes->{{3.6280076947232428`*^9, 3.628007718690366*^9}, {
   3.62800777081297*^9, 3.6280078137696123`*^9}, {3.6280140409873238`*^9, 
   3.62801408788243*^9}, {3.628014227361739*^9, 3.628014266609626*^9}, {
   3.628014377062807*^9, 3.628014420199849*^9}, {3.628014453648635*^9, 
   3.628014457910605*^9}, {3.6288768852690973`*^9, 3.6288768976343822`*^9}, 
   3.630421028652648*^9, {3.647880147320936*^9, 3.6478802224842453`*^9}}],

Cell[BoxData[
 RowBox[{"DotPlot", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", ".03", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], "}"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"4", ",", "1"}], "}"}], "}"}], "]"}], ",", 
      RowBox[{"PointSize", "[", ".06", "]"}], ",", "Blue", ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "3"}], "}"}], "}"}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "6"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.628014147221897*^9, 3.6280142200832863`*^9}, {
  3.628014270950205*^9, 3.628014347697541*^9}, {3.62801446166013*^9, 
  3.628014464166868*^9}, {3.628014832730637*^9, 3.628014833875457*^9}, {
  3.647880127151537*^9, 3.6478801410724373`*^9}, {3.647880233959628*^9, 
  3.647880253419428*^9}}],

Cell[TextData[{
 "Now imagine drawing line segments from the origin ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 ", from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"5", ",", "3"}], ")"}], TraditionalForm]]],
 ", from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"5", ",", "3"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 ", and from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 " back to the origin ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 ".  It appears that we have created a ",
 StyleBox[ButtonBox["parallelogram",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Parallelogram"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Parallelogram"],
  FontColor->RGBColor[0, 0, 1]],
 ".  Thinking in terms of vectors, it appears that if we let ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " be a vector pointing from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 " and let ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " be a vector pointing from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 ", then after an appropriate translation, ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " will point from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"5", ",", "3"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " will point from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"5", ",", "3"}], ")"}], TraditionalForm]]],
 ".  This can be confirmed visually with the next line of code (make sure the \
preceding line of code has been entered before entering this line so that the \
variable ",
 StyleBox["DotPlot",
  FontWeight->"Bold"],
 " has a \[OpenCurlyDoubleQuote]value\[CloseCurlyDoubleQuote])."
}], "Text",
 CellChangeTimes->{{3.628014471381733*^9, 3.628014849064849*^9}, {
  3.6288769242177896`*^9, 3.628876925500538*^9}, {3.647880285922982*^9, 
  3.6478803024170027`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"DotPlot", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", ".01", "]"}], ",", "Brown", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "3"}], "}"}]}], "}"}], "]"}], ",", "Orange", ",", 
      
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"4", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "3"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6280148250998297`*^9, 3.628014939732933*^9}, {
  3.647880315187766*^9, 3.6478803192961884`*^9}}],

Cell[TextData[{
 "In fact, we can \[OpenCurlyDoubleQuote]quantify\[CloseCurlyDoubleQuote] ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " by describing their ",
 StyleBox[ButtonBox["horizontal and vertical displacements",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.physicsclassroom.com/class/vectors/Lesson-2/Horizontal-\
and-Vertical-Displacement"], None},
  ButtonNote->
   "http://www.physicsclassroom.com/class/vectors/Lesson-2/Horizontal-and-\
Vertical-Displacement"],
  FontColor->RGBColor[0, 0, 1]],
 "; any vector is completely determined, within a given rectangular \
coordinate system, by how much it points to the ",
 StyleBox["right",
  FontSlant->"Italic"],
 " (",
 StyleBox["positive",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " horizontal displacement) or ",
 StyleBox["left",
  FontSlant->"Italic"],
 " (",
 StyleBox["negative",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " horizontal displacement) and by how much it points ",
 StyleBox["upward",
  FontSlant->"Italic"],
 " (",
 StyleBox["positive",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " vertical displacement) or ",
 StyleBox["downward",
  FontSlant->"Italic"],
 " (",
 StyleBox["negative",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " vertical displacement). For the example above, ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " has a horizontal displacement of 4 and a vertical displacement of 1; while \
",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " has a horizontal displacement of 1 and a vertical displacement of 2.  It\
\[CloseCurlyQuote]s no accident that these numbers match the coordinates of \
the points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 ", respectively; and it\[CloseCurlyQuote]s also no accident that these \
numbers match the real and imaginary parts of the complex numbers ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "+", "\[ImaginaryI]"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ", respectively.  Finally, note that we can also obtain these displacements \
by subtracting the coordinates of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "2"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 ", respectively, from the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"5", ",", "3"}], ")"}], TraditionalForm]]],
 ".  This is essentially a geometric ",
 StyleBox[ButtonBox["proof",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Mathematical_proof"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Mathematical_proof"],
  FontColor->RGBColor[0, 0, 1]],
 " that the figure in the picture is a ",
 StyleBox[ButtonBox["parallelogram",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Parallelogram"], None},
  ButtonNote->"http://en.wikipedia.org/wiki/Parallelogram"],
  FontColor->RGBColor[0, 0, 1]],
 ", and it leads us to write ",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["w",
    FontWeight->"Bold",
    FontSlant->"Plain"], TraditionalForm]]],
 " in a new way.  One common notation used for these vectors is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["v",
     FontWeight->"Bold",
     FontSlant->"Plain"], "=", 
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{"4", ",", "1"}], "\[RightAngleBracket]"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["w",
     FontWeight->"Bold",
     FontSlant->"Plain"], "=", 
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{"1", ",", "2"}], "\[RightAngleBracket]"}]}], TraditionalForm]]],
 ", and this is the notation we will use.  In physics, the standard way to \
represent these vectors is in terms of the \[OpenCurlyDoubleQuote]",
 StyleBox[ButtonBox["standard unit vectors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Unit_vector#Cartesian_coordinates"], 
    None},
  ButtonNote->
   "http://en.wikipedia.org/wiki/Unit_vector#Cartesian_coordinates"],
  FontColor->RGBColor[0, 0, 1]],
 "\[CloseCurlyDoubleQuote].  We will ",
 StyleBox["not",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " use that notation, because of the obvious confusion that could arise when \
using it within the study of complex numbers through the use of the \
\[OpenCurlyDoubleQuote]i\[CloseCurlyDoubleQuote] in that notation (also \
called \[OpenCurlyDoubleQuote]i hat\[CloseCurlyDoubleQuote] and written ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["i", "^"], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->{{3.6280149709829082`*^9, 3.62801513939699*^9}, {
  3.628015220407031*^9, 3.628015220409556*^9}, {3.628015290772086*^9, 
  3.628015607410637*^9}, {3.628015710386314*^9, 3.628015744694153*^9}, {
  3.628015775660411*^9, 3.628015796492584*^9}, {3.628015830467173*^9, 
  3.628015988904243*^9}, {3.6304211768106937`*^9, 3.6304211896416187`*^9}}],

Cell[TextData[{
 "What we have just done, for the given example, is confirmed that complex \
number addition also satisfies the parallelogram law, just as vector addition \
does. In fact, the ",
 StyleBox[ButtonBox["extended view of vector addition",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.virtualnerd.com/intro-physics/vectors/addition-\
subtraction/add-subtract-multiple-vectors/add-head-tail-three-vector"], None},
  
  ButtonNote->
   "http://www.virtualnerd.com/intro-physics/vectors/addition-subtraction/add-\
subtract-multiple-vectors/add-head-tail-three-vector"],
  FontColor->RGBColor[0, 0, 1]],
 " works when we add three or more complex numbers.  We will therefore want \
visualize complex numbers as vectors when we add them."
}], "Text",
 CellChangeTimes->{{3.6280160200716467`*^9, 3.6280161701999598`*^9}, {
  3.647880485020097*^9, 3.64788048502352*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" Exercise 2:",
  FontWeight->"Bold"],
 "  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to visually illustrate the sum of the complex numbers ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "5"}], "+", 
    RowBox[{"4", "\[ImaginaryI]"}]}], TraditionalForm]]],
 " as equivalent to the addition of the vectors ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftAngleBracket]", 
    RowBox[{"3", ",", "2"}], "\[RightAngleBracket]"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftAngleBracket]", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "4"}], "\[RightAngleBracket]"}], 
   TraditionalForm]]],
 ".  What is different about the parallelogram so generated compared to the \
parallelogram created with the example above?  Use the ",
 StyleBox[ButtonBox["distance formula",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.purplemath.com/modules/distform.htm"], None},
  ButtonNote->"http://www.purplemath.com/modules/distform.htm"],
  FontColor->RGBColor[0, 0, 1]],
 " to confirm that opposing sides of this parallelogram have the same length \
and use facts from trigonometry, such as the ",
 StyleBox[ButtonBox["Law of Cosines",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.mathsisfun.com/algebra/trig-cosine-law.html"], None},
  ButtonNote->"http://www.mathsisfun.com/algebra/trig-cosine-law.html"],
  FontColor->RGBColor[0, 0, 1]],
 ", to confirm that opposing angles of this parallelogram have the same \
measure."
}], "Subsection",
 CellChangeTimes->{{3.6276557036467533`*^9, 3.627655717913577*^9}, {
   3.627655764618641*^9, 3.62765590921062*^9}, {3.627656765938553*^9, 
   3.627656864463704*^9}, {3.627656948349906*^9, 3.627656997576027*^9}, {
   3.627657059639831*^9, 3.6276571369713497`*^9}, {3.627657178490571*^9, 
   3.627657203292487*^9}, {3.6276573617503653`*^9, 3.627657361906416*^9}, {
   3.627657492593141*^9, 3.6276575163946*^9}, {3.627659108756077*^9, 
   3.627659190362417*^9}, {3.627908677348465*^9, 3.6279087177368393`*^9}, {
   3.627915943542495*^9, 3.627915953032187*^9}, {3.62791602506989*^9, 
   3.627916047611404*^9}, {3.627916089879258*^9, 3.6279161105186167`*^9}, 
   3.6280059612857428`*^9, {3.628016222252342*^9, 3.628016460612976*^9}, {
   3.628016498207847*^9, 3.6280164982123003`*^9}, {3.6280165432046423`*^9, 
   3.6280165480001173`*^9}, {3.628016599170849*^9, 3.628016599174406*^9}, {
   3.6288770389034233`*^9, 3.628877045706953*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Work 2: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659434447322*^9, 3.627659440180417*^9}, {3.627659519063675*^9, 
  3.6276595191998262`*^9}, {3.6280162311838093`*^9, 3.628016231340686*^9}}],

Cell[TextData[{
 StyleBox["(Enter your code under this cell when ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0.67, 0]],
 StyleBox[" is in \[OpenCurlyDoubleQuote]Input mode\[CloseCurlyDoubleQuote] \
\[LongDash] make sure a horizontal line is showing before you start typing)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.67, 0]]
}], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659460201036*^9, 3.627659504551834*^9}}],

Cell[TextData[StyleBox["(You can type your thoughts and answers here \
formatted in text mode)",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0.67, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659537608328*^9}, {3.627659670483754*^9, 
  3.627659682423826*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Grader/Instructor ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Assessment 2: "
}], "Subsubsection",
 CellChangeTimes->{{3.627658284055971*^9, 3.627658317587431*^9}, {
  3.627659516682569*^9, 3.627659516839205*^9}, {3.627659556506875*^9, 
  3.62765955845679*^9}, {3.627659617632988*^9, 3.627659649751532*^9}, {
  3.628016233684417*^9, 3.6280162337884083`*^9}}],

Cell[TextData[StyleBox["(The grader/instructor will give you feedback about \
your work here)",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.6276582897121067`*^9, 3.627658333401252*^9}, {
  3.627659535820641*^9, 3.627659578217204*^9}, {3.627659621472638*^9, 
  3.627659622910438*^9}, {3.628006013730137*^9, 3.6280060155901546`*^9}, {
  3.628877211175973*^9, 3.628877213714664*^9}}],

Cell[TextData[{
 "In Activity 3 of this learning module on complex addition and the complex \
plane, we will use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Manipulate.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Manipulate.html"],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0.5, 0]],
 " function to create dynamic (interactive) versions of these diagrams.  We \
will also delve into the algebraic and geometric meanings of complex number \
subtraction."
}], "Text",
 CellChangeTimes->{{3.647880554565959*^9, 3.6478806593359537`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1247, 676},
WindowMargins->{{-15, Automatic}, {-24, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 428, 11, 183, "Title"],
Cell[CellGroupData[{
Cell[1939, 50, 209, 3, 78, "Subchapter"],
Cell[2151, 55, 3099, 76, 175, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5287, 136, 281, 4, 78, "Subchapter"],
Cell[5571, 142, 1009, 20, 115, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6617, 167, 305, 4, 78, "Subchapter"],
Cell[6925, 173, 3729, 83, 158, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10691, 261, 250, 3, 97, "Subchapter"],
Cell[10944, 266, 1300, 22, 257, "Text"],
Cell[12247, 290, 1044, 16, 257, "Text"],
Cell[CellGroupData[{
Cell[13316, 310, 1633, 25, 463, "Subsection"],
Cell[CellGroupData[{
Cell[14974, 339, 152, 2, 102, "Subsubsection"],
Cell[15129, 343, 327, 6, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15493, 354, 263, 3, 102, "Subsubsection"],
Cell[15759, 359, 420, 7, 88, "Text"],
Cell[16182, 368, 2079, 51, 321, "Text"],
Cell[18264, 421, 1045, 25, 147, "Text"],
Cell[19312, 448, 316, 9, 87, "Input"],
Cell[19631, 459, 988, 28, 206, "Text"],
Cell[20622, 489, 581, 19, 87, "Input"],
Cell[21206, 510, 2195, 54, 147, "Text"],
Cell[23404, 566, 982, 25, 137, "Input"],
Cell[24389, 593, 3340, 92, 268, "Text"],
Cell[27732, 687, 5443, 153, 547, "Input"],
Cell[33178, 842, 3740, 97, 331, "Text"],
Cell[36921, 941, 4873, 133, 445, "Input"],
Cell[41797, 1076, 1187, 28, 147, "Text"],
Cell[42987, 1106, 4964, 135, 496, "Input"],
Cell[47954, 1243, 669, 13, 206, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48672, 1262, 4193, 104, 657, "Subsection"],
Cell[CellGroupData[{
Cell[52890, 1370, 264, 7, 102, "Subsubsection"],
Cell[53157, 1379, 573, 14, 147, "Text"],
Cell[53733, 1395, 327, 6, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54097, 1406, 336, 8, 102, "Subsubsection"],
Cell[54436, 1416, 420, 7, 88, "Text"],
Cell[54859, 1425, 4191, 129, 438, "Text"],
Cell[59053, 1556, 186, 4, 88, "Text"],
Cell[59242, 1562, 3385, 95, 343, "Input"],
Cell[62630, 1659, 2521, 65, 265, "Text"],
Cell[65154, 1726, 2631, 75, 238, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67834, 1807, 2318, 57, 438, "Subsection"],
Cell[CellGroupData[{
Cell[70177, 1868, 203, 3, 102, "Subsubsection"],
Cell[70383, 1873, 327, 6, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70747, 1884, 312, 4, 102, "Subsubsection"],
Cell[71062, 1890, 420, 7, 88, "Text"],
Cell[71485, 1899, 5865, 154, 610, "Text"],
Cell[77353, 2055, 3094, 75, 321, "Text"],
Cell[80450, 2132, 1648, 44, 188, "Input"],
Cell[82101, 2178, 3210, 121, 321, "Text"],
Cell[85314, 2301, 1263, 38, 188, "Input"],
Cell[86580, 2341, 5618, 174, 682, "Text"],
Cell[92201, 2517, 891, 18, 206, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93141, 2541, 2660, 63, 507, "Subsection"],
Cell[CellGroupData[{
Cell[95826, 2608, 312, 7, 102, "Subsubsection"],
Cell[96141, 2617, 573, 14, 147, "Text"],
Cell[96717, 2633, 327, 6, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97081, 2644, 387, 9, 102, "Subsubsection"],
Cell[97471, 2655, 420, 7, 88, "Text"],
Cell[97894, 2664, 742, 17, 206, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature kxplvJ7ps2G@kD13YhaK@j9z *)
