(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    147673,       3934]
NotebookOptionsPosition[    143158,       3815]
NotebookOutlinePosition[    143570,       3833]
CellTagsIndexPosition[    143527,       3830]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Dynamic Versions of Figures from Tristan \
Needham\[CloseCurlyQuote]s ",
  FontSize->72,
  FontWeight->"Bold"],
 StyleBox[ButtonBox["Visual Complex Analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?ie=UTF8&qid=1420913852&sr=8-1&keywords=visual+complex+\
analysis"], None},
  ButtonNote->
   "http://www.amazon.com/Visual-Complex-Analysis-Tristan-Needham/dp/\
0198534469/ref=sr_1_1?ie=UTF8&qid=1420913852&sr=8-1&keywords=visual+complex+\
analysis"],
  FontSize->72,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]
}], "Subsection",
 CellChangeTimes->{{3.6297303769432163`*^9, 3.629730407739004*^9}, 
   3.629906937354287*^9, {3.6785423692904577`*^9, 3.6785423708966017`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["This document contains finished code to generate interactive \
versions of the pictures in ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Visual Complex Analysis",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".  Educational modules could be made that are centered around \
understanding the mathematics underlying this code and constructing the code.",
  FontColor->RGBColor[0, 0, 1]]
}], "Section",
 CellChangeTimes->{{3.6785422694940357`*^9, 3.6785423326904182`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Geometric Intepretation of Complex Multiplication",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" ",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox["(Chapter 1, Figures 1 and 2 (pages 2 and 3))",
  FontSize->32,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]]
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.6146916072058992`*^9, 3.614691608085576*^9}, {
   3.614691884976777*^9, 3.61469188765825*^9}, {3.614965995418138*^9, 
   3.61496600532577*^9}, {3.6297305138202333`*^9, 3.6297305155783*^9}, 
   3.629734335167334*^9, {3.629903533817162*^9, 3.629903564654172*^9}, 
   3.678542228353161*^9}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ProductPt", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pt1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"I", "*", 
            RowBox[{"pt1", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pt2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"I", "*", 
            RowBox[{"pt2", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], "]"}], ",", 
       RowBox[{"Im", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pt1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"I", "*", 
            RowBox[{"pt1", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"pt2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{"I", "*", 
            RowBox[{"pt2", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], "]"}]}], "}"}]}], 
    ";", 
    RowBox[{"Grid", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"pt1", ",", "pt2"}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".05", "]"}]}], "}"}], "}"}]}]}], 
           "]"}], ",", 
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                   RowBox[{"I", "*", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                   RowBox[{"I", "*", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                   RowBox[{"I", "*", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                   RowBox[{"I", "*", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], "]"}]}], 
              "}"}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Magenta", ",", 
                RowBox[{"PointSize", "[", ".05", "]"}]}], "}"}], "}"}]}]}], 
           "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Thick", ",", "Blue", ",", 
             RowBox[{"Arrow", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", "pt1", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", "pt2"}], "}"}], "]"}], 
             ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "+", 
                  FractionBox[
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "/", "5"}], ")"}], "*", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], 
                   RowBox[{"Norm", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]]}]}], 
                "]"}], ",", "Large"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "+", 
                  FractionBox[
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "/", "5"}], ")"}], "*", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], 
                   RowBox[{"Norm", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]]}]}], 
                "]"}], ",", "Large"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Thick", ",", "Brown", ",", 
             RowBox[{"Arrow", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", "ProductPt"}], "}"}], 
              "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\!\(\*SubscriptBox[\(z\
\), \(2\)]\)\>\"", ",", 
                 RowBox[{"ProductPt", "+", 
                  FractionBox[
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "/", "5"}], ")"}], "*", "ProductPt"}], 
                   RowBox[{"Norm", "[", "ProductPt", "]"}]]}]}], "]"}], ",", 
               "Large"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "R"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
              "]"}], ",", 
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], 
               "]"}], "]"}]}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
          RowBox[{"TicksStyle", "\[Rule]", "Large"}]}], "]"}], ",", ",", ",", 
        
        RowBox[{"Column", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", 
                 "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                    RowBox[{"\[ImaginaryI]", "*", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ",", "Large"}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", 
                 "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                    RowBox[{"\[ImaginaryI]", "*", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ",", "Large"}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<\!\(\*SubscriptBox[\(z\), \
\(1\)]\)\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", "]"}], ",", "Large"}], "]"}],
               ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", 
                    RowBox[{"\[ImaginaryI]", "*", 
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], ",", "Large"}], "]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<\[LeftBracketingBar]\!\(\*SubscriptBox[\(z\), \(1\)]\)\
\[RightBracketingBar]\>\"", "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{"Norm", "[", "pt1", "]"}], "]"}], ",", "Large"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<\[LeftBracketingBar]\!\(\*SubscriptBox[\(z\), \(2\)]\)\
\[RightBracketingBar]\>\"", "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{"Norm", "[", "pt2", "]"}], "]"}], ",", "Large"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<\[LeftBracketingBar]\!\(\*SubscriptBox[\(z\), \
\(1\)]\)\!\(\*SubscriptBox[\(z\), \(2\)]\)\[RightBracketingBar]\>\"", "]"}], 
                ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{"Norm", "[", "ProductPt", "]"}], "]"}], ",", 
                    "Large"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<Arg(\!\(\*SubscriptBox[\(z\), \(1\)]\)) (degrees)\>\"", 
                 "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}], "]"}], ",", "Large"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<Arg(\!\(\*SubscriptBox[\(z\), \(2\)]\)) (degrees)\>\"", 
                 "]"}], ",", "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}], "]"}], ",", "Large"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<Arg(\!\(\*SubscriptBox[\(z\), \
\(1\)]\)\!\(\*SubscriptBox[\(z\), \(2\)]\)) (degrees)\>\"", "]"}], ",", 
                "Large"}], "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "\[Pi]"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
                    "Large"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<Arg(\!\(\*SubscriptBox[\(z\), \
\(1\)]\))+Arg(\!\(\*SubscriptBox[\(z\), \(2\)]\))\>\"", "]"}], ",", "Large"}],
                "]"}], ",", "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}], "+", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}]}], "]"}], ",", "Large"}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], "]"}],
            ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{
                "Text", "[", 
                 "\"\<\[LeftBracketingBar]Arg(\!\(\*SubscriptBox[\(z\), \
\(1\)]\))+Arg(\!\(\*SubscriptBox[\(z\), \
\(2\)]\))-Arg(\!\(\*SubscriptBox[\(z\), \(1\)]\)\!\(\*SubscriptBox[\(z\), \(2\
\)]\))\[RightBracketingBar]\>\"", "]"}], ",", "Large"}], "]"}], ",", 
              "\"\< \!\(\*
StyleBox[\"=\",
FontSize->24]\) \>\"", ",", 
              RowBox[{"Item", "[", 
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}], "+", 
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"pt2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                    RowBox[{"180", "/", "\[Pi]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "\[Pi]"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"ProductPt", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "]"}],
                     ",", "Large"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"6", ",", "4"}], "}"}]}], "]"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "}"}], 
            "]"}]}], "}"}], "]"}]}], "}"}], "}"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", "Locator"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", "Locator"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"R", ",", "5"}], "}"}], ",", ".1", ",", "200"}], "}"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.578839096235717*^9, 3.578839155547014*^9}, {
   3.578839188532435*^9, 3.578839203932845*^9}, {3.578839249253716*^9, 
   3.5788392918489017`*^9}, {3.578839330939101*^9, 3.578839406927783*^9}, {
   3.5788394581843443`*^9, 3.578839611927758*^9}, {3.578839655758849*^9, 
   3.578839737844182*^9}, {3.578839993846998*^9, 3.578840017426097*^9}, {
   3.5788402193827133`*^9, 3.578840417296136*^9}, {3.578840451897037*^9, 
   3.578840559628662*^9}, {3.578840606551066*^9, 3.5788406700907803`*^9}, {
   3.579878322945691*^9, 3.579878419260413*^9}, {3.5798784562579403`*^9, 
   3.579878642990127*^9}, {3.579881766145698*^9, 3.579881771114188*^9}, {
   3.6146919168525333`*^9, 3.61469198144009*^9}, {3.614692013120747*^9, 
   3.614692058588027*^9}, {3.614692141650285*^9, 3.6146921768799963`*^9}, {
   3.614956236221129*^9, 3.614956286618469*^9}, {3.6149563353096857`*^9, 
   3.614956364727042*^9}, {3.614958089259659*^9, 3.6149582173018513`*^9}, {
   3.614958265593672*^9, 3.6149582883033333`*^9}, {3.614958427091219*^9, 
   3.614958446655376*^9}, {3.614958517267633*^9, 3.61495853674277*^9}, {
   3.614958596969275*^9, 3.6149586256321783`*^9}, {3.6149587165498323`*^9, 
   3.614958791785552*^9}, 3.6149588454856777`*^9, {3.614958876447362*^9, 
   3.61495888101764*^9}, {3.614958924424082*^9, 3.614958957807036*^9}, {
   3.6149589883021727`*^9, 3.614959000549244*^9}, {3.614959042007183*^9, 
   3.614959077783205*^9}, {3.614959181479498*^9, 3.614959311395401*^9}, {
   3.6149621488929787`*^9, 3.614962211431136*^9}, {3.614963115874262*^9, 
   3.614963247755034*^9}, {3.614963328433557*^9, 3.614963386611196*^9}, {
   3.614963466632495*^9, 3.6149634716720877`*^9}, {3.614963613936721*^9, 
   3.614963644348427*^9}, {3.614963674745844*^9, 3.614963693001793*^9}, {
   3.615231002587042*^9, 3.615231029943823*^9}, {3.629730461402843*^9, 
   3.629730492481889*^9}, 3.629734335171335*^9, {3.629903226380992*^9, 
   3.629903296974266*^9}, {3.648311811704013*^9, 3.648311812758018*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["The Geometry of Euler\[CloseCurlyQuote]s Identity",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[" (Chapter 1, Figure 9 (page 13))",
  FontSize->32,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.614959516350266*^9, 3.61495951758083*^9}, {
   3.614966007517912*^9, 3.6149660161159143`*^9}, {3.629730530698913*^9, 
   3.6297305328011007`*^9}, 3.629734323798121*^9, {3.6299036214358883`*^9, 
   3.629903639259284*^9}, {3.629903692478627*^9, 3.629903696090476*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["P", "0"], "[", "x_", "]"}], ":=", "1"}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["P", "n_"], "[", "x_", "]"}], ":=", 
   RowBox[{"1", "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{
      RowBox[{"x", "^", 
       RowBox[{"(", "k", ")"}]}], "/", 
      RowBox[{"k", "!"}]}]}]}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Circle", "[", "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".01", "]"}], ",", "Red", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
           RowBox[{"Thickness", "[", ".01", "]"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"OddQ", "[", "i", "]"}], ",", "Red", ",", "Blue"}], 
            "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 SubscriptBox["P", "i"], "[", "\[Theta]", "]"}], ",", "0"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 SubscriptBox["P", 
                  RowBox[{"i", "+", "1"}]], "[", "\[Theta]", "]"}], ",", 
                "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "step"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".01", "]"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"OddQ", "[", "i", "]"}], ",", "Red", ",", "Blue"}], 
            "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Re", "[", 
                 RowBox[{
                  SubscriptBox["P", "i"], "[", 
                  RowBox[{"I", "*", "\[Theta]"}], "]"}], "]"}], ",", 
                RowBox[{"Im", "[", 
                 RowBox[{
                  SubscriptBox["P", "i"], "[", 
                  RowBox[{"I", "*", "\[Theta]"}], "]"}], "]"}]}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Re", "[", 
                 RowBox[{
                  SubscriptBox["P", 
                   RowBox[{"i", "+", "1"}]], "[", 
                  RowBox[{"I", "*", "\[Theta]"}], "]"}], "]"}], ",", 
                RowBox[{"Im", "[", 
                 RowBox[{
                  SubscriptBox["P", 
                   RowBox[{"i", "+", "1"}]], "[", 
                  RowBox[{"I", "*", "\[Theta]"}], "]"}], "]"}]}], "}"}]}], 
             "}"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "step"}], "}"}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", ".01", "]"}], ",", "Magenta", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], "}"}], 
          "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"(", "\[Theta]", ")"}]}], ",", "0"}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "R"}], "/", "3"}], ",", "R"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "R"}], "/", "3"}], ",", 
           RowBox[{"R", "/", "2"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", 
        RowBox[{"Pi", "/", "12"}]}], "}"}], ",", "0", ",", 
      RowBox[{"3", 
       RowBox[{"\[Pi]", "/", "2"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"step", ",", "0", ",", "10", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"R", ",", "4"}], "}"}], ",", "2", ",", "120"}], "}"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.614959557193214*^9, 3.6149596453646584`*^9}, {
   3.614959699593728*^9, 3.614959713720973*^9}, {3.614959754665937*^9, 
   3.614959828750173*^9}, {3.614959902443405*^9, 3.614960008980073*^9}, {
   3.6149601140831337`*^9, 3.614960194093091*^9}, {3.614960227337036*^9, 
   3.614960231440145*^9}, {3.614960261564231*^9, 3.614960341409602*^9}, {
   3.614960476386447*^9, 3.614960508121482*^9}, {3.614960559714752*^9, 
   3.614960563173181*^9}, {3.6149605959808207`*^9, 3.614960671836638*^9}, {
   3.614960702400271*^9, 3.6149608241151876`*^9}, {3.61496093630752*^9, 
   3.6149609654282427`*^9}, {3.614961001518083*^9, 3.614961014391755*^9}, {
   3.6149613334647427`*^9, 3.6149613359187603`*^9}, {3.614961943586084*^9, 
   3.614962003487328*^9}, {3.6149620367117977`*^9, 3.614962046704811*^9}, {
   3.614962227725747*^9, 3.614962371431909*^9}, {3.614962401994198*^9, 
   3.6149624828475657`*^9}, {3.614962519604487*^9, 3.614962533074876*^9}, {
   3.614962566150118*^9, 3.614962566464423*^9}, {3.6149626186909323`*^9, 
   3.614962673480385*^9}, {3.614962708787897*^9, 3.614962718561967*^9}, {
   3.6149627764798803`*^9, 3.614962795054631*^9}, {3.614962833173727*^9, 
   3.614962838198463*^9}, {3.614964095433323*^9, 3.614964119046571*^9}, {
   3.614964177227293*^9, 3.6149642129471493`*^9}, {3.614964366484972*^9, 
   3.614964456754614*^9}, {3.614964490114325*^9, 3.614964535870606*^9}, {
   3.614964568533229*^9, 3.614964594297866*^9}, {3.629730576672447*^9, 
   3.629730622850329*^9}, 3.629734323801414*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Line Segments between Centers of Opposite Squares Constructed on \
the Sides of a Quadrilateral are Perpendicular and of Equal Length",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" (Chapter 1, Figure 12 (page 16))",
  FontSize->32,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]]
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.614964633918195*^9, 3.614964634891927*^9}, {
   3.614966027502459*^9, 3.614966029071067*^9}, {3.6297307775456743`*^9, 
   3.629730778944248*^9}, {3.629731084281814*^9, 3.629731084351495*^9}, 
   3.629734317940736*^9, {3.629903850988532*^9, 3.62990389288188*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{
      RowBox[{"a", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", "I"}]}]}], ";", 
    RowBox[{"B", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"b", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", "I"}]}], ")"}], "-", "A"}]}], 
    ";", 
    RowBox[{"Ce", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", "I"}]}], ")"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"b", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", "I"}]}], ")"}]}]}], ";", 
    RowBox[{"De", "=", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", "I"}]}], ")"}]}]}], ";", 
    RowBox[{"p", "=", 
     RowBox[{"a", "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"A", "*", "I"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"A", "*", "I"}], "]"}]}], "}"}]}]}], ";", 
    RowBox[{"q", "=", 
     RowBox[{
      RowBox[{"2", "a"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", "B", "]"}], ",", 
        RowBox[{"Im", "[", "B", "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"B", "*", "I"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"B", "*", "I"}], "]"}]}], "}"}]}]}], ";", 
    RowBox[{"r", "=", 
     RowBox[{
      RowBox[{"2", "a"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"2", "B"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"2", "B"}], "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", "Ce", "]"}], ",", 
        RowBox[{"Im", "[", "Ce", "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Ce", "*", "I"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"Ce", "*", "I"}], "]"}]}], "}"}]}]}], ";", 
    RowBox[{"s", "=", 
     RowBox[{
      RowBox[{"2", "a"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"2", "B"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"2", "B"}], "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"2", "Ce"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"2", "Ce"}], "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", "De", "]"}], ",", 
        RowBox[{"Im", "[", "De", "]"}]}], "}"}], "+", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"De", "*", "I"}], "]"}], ",", 
        RowBox[{"Im", "[", 
         RowBox[{"De", "*", "I"}], "]"}]}], "}"}]}]}], ";", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"2", "a"}], ",", 
            RowBox[{
             RowBox[{"2", "a"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "A", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "A", "*", "I"}], "]"}]}], "}"}]}], ",", 
            RowBox[{
             RowBox[{"2", "a"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "A", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "A", "*", "I"}], "]"}]}], "}"}], "-", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "A"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "A"}], "]"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}],
        "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "a"}], ",", 
            RowBox[{"2", "b"}], ",", 
            RowBox[{
             RowBox[{"2", "b"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "B", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "B", "*", "I"}], "]"}]}], "}"}]}], ",", 
            RowBox[{
             RowBox[{"2", "b"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "B", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "B", "*", "I"}], "]"}]}], "}"}], "-", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "B"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "B"}], "]"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}],
        "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "b"}], ",", 
            RowBox[{"2", "c"}], ",", 
            RowBox[{
             RowBox[{"2", "c"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "Ce", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "Ce", "*", "I"}], "]"}]}], "}"}]}], ",", 
            RowBox[{
             RowBox[{"2", "c"}], "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "Ce", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "Ce", "*", "I"}], "]"}]}], "}"}], "-", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "Ce"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "Ce"}], "]"}]}], "}"}]}]}], "}"}], "]"}]}], 
        "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Magenta", ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "c"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"2", "De", "*", "I"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"2", "De", "*", "I"}], "]"}]}], "}"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "De", "*", "I"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "De", "*", "I"}], "]"}]}], "}"}], "-", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{"2", "De"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{"2", "De"}], "]"}]}], "}"}]}]}], "}"}], "]"}]}], 
        "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"2", "a"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "a"}], ",", 
            RowBox[{"2", "b"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "b"}], ",", 
            RowBox[{"2", "c"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "c"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
      ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", ".02", "]"}], ",", "Brown", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"p", ",", "r"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", ".02", "]"}], ",", "Brown", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"q", ",", "s"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", ".04", "]"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}], ",", "Locator"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", "Locator"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", 
         RowBox[{"-", "2.5"}]}], "}"}]}], "}"}], ",", "Locator"}], "}"}]}], 
  "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.61496617516455*^9, 3.614966257676876*^9}, {
   3.614966289239464*^9, 3.6149663933131733`*^9}, {3.614966461381687*^9, 
   3.61496678082097*^9}, {3.614966874224908*^9, 3.614966910051374*^9}, {
   3.614966950592505*^9, 3.614966985955598*^9}, {3.614967018102008*^9, 
   3.6149670187653217`*^9}, 3.615219480670042*^9, {3.615219652564568*^9, 
   3.615219667323279*^9}, {3.6152198309891167`*^9, 3.615220047174302*^9}, {
   3.615220126394597*^9, 3.615220157515136*^9}, {3.615220197963669*^9, 
   3.615220453367147*^9}, {3.615220561656671*^9, 3.615220739230706*^9}, {
   3.615220772690405*^9, 3.615220830910882*^9}, 3.6297306934294033`*^9, {
   3.6297307378458357`*^9, 3.6297307663925133`*^9}, 3.629734317944027*^9, {
   3.629903753453803*^9, 3.629903757756448*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Commutativity of Translation Compositions",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[" (Chapter 1, Figure 13a (page 18))",
  FontSize->32,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.6155667952671757`*^9, 3.615566805482983*^9}, {
   3.629730904781117*^9, 3.629730906027355*^9}, 3.629734304383952*^9, {
   3.6299040709943113`*^9, 3.629904084750576*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FilledTriangle", "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "]"}], ":=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";", 
  RowBox[{
   RowBox[{"UnFilledTriangle", "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "]"}], ":=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", ".01", "]"}], ",", "Dashed", ",", "Green", 
      ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "a"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";", 
  RowBox[{"BaseTriangle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", ".5"}], "}"}]}], "}"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"FilledTriangle", "[", "BaseTriangle", "]"}], ",", 
      RowBox[{"FilledTriangle", "[", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", "<", ".5"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1000", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1001", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1000", ",", ".5"}], "}"}]}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"BaseTriangle", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "+", "v"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "]"}], "]"}],
       ",", 
      RowBox[{"FilledTriangle", "[", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", "<", ".99"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1000", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1001", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1000", ",", ".5"}], "}"}]}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"BaseTriangle", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "+", "v", "+", "w"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "]"}], "]"}],
       ",", 
      RowBox[{"UnFilledTriangle", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"BaseTriangle", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "+", "w"}], ")"}], "*", "\[Lambda]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "<", ".5"}], ",", 
        RowBox[{"UnFilledTriangle", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"BaseTriangle", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "+", 
            RowBox[{"v", "*", "2", "\[Lambda]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"UnFilledTriangle", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"BaseTriangle", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "+", "v", "+", 
            RowBox[{"w", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", "\[Lambda]"}], "-", "1"}], ")"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}], "]"}],
       ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", ".01", "]"}], ",", "Red", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "v"}], "}"}], "]"}], ",", 
         RowBox[{"Thickness", "[", ".01", "]"}], ",", "Blue", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"v", "+", "w"}]}], "}"}], "]"}], ",", 
         RowBox[{"Thickness", "[", ".01", "]"}], ",", "Purple", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"v", "+", "w"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", "Large"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"v", ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", "Locator"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"w", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "3"}], "}"}]}], "}"}], ",", "Locator"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.615566860741461*^9, 3.6155668873971024`*^9}, {
   3.615566926427387*^9, 3.6155670913942204`*^9}, {3.61556715190252*^9, 
   3.615567153725363*^9}, {3.615567192540279*^9, 3.615567407575034*^9}, {
   3.615567476670988*^9, 3.61556761216558*^9}, {3.615567649585412*^9, 
   3.6155676973909473`*^9}, {3.615567742115655*^9, 3.615567876910307*^9}, {
   3.615567907064879*^9, 3.615567907695429*^9}, {3.629730797414855*^9, 
   3.6297308802818832`*^9}, 3.6297343043872557`*^9, {3.629904004276484*^9, 
   3.629904028232373*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["How the Trajectory of  ",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Z", "(", "t", ")"}], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", 
         RowBox[{"b", " ", "\[ImaginaryI]"}]}], ")"}], "t"}]], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"a", " ", "t"}]}]], 
       RowBox[{"cos", "(", 
        RowBox[{"b", " ", "t"}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"a", " ", "t"}]}]], 
       RowBox[{"sin", "(", 
        RowBox[{"b", " ", "t"}], ")"}]}]}]}]}], TraditionalForm]],
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox["  changes as ",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "+", 
    RowBox[{"b", " ", "\[ImaginaryI]"}]}], TraditionalForm]],
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" changes and how the velocity vector ",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "(", "t", ")"}], TraditionalForm]],
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" is the limiting value of ",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"Z", "(", 
      RowBox[{"t", "+", "\[Delta]"}], ")"}], "-", 
     RowBox[{"Z", "(", "t", ")"}]}], "\[Delta]"], TraditionalForm]],
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" as ",
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "\[LongRightArrow]", "0"}], TraditionalForm]],
  FontSize->48,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" (Chapter 1, Figure 16 (page 21))",
  FontSize->32,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]]
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.6152321206505327`*^9, 3.615232128040956*^9}, {
   3.62973093644646*^9, 3.629730937772031*^9}, 3.6297342886241493`*^9, {
   3.629904775860531*^9, 3.629904958882743*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", 
     RowBox[{"a_", ",", "b_"}]], "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"a", "*", "t"}], ")"}]}], "*", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "b", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["V", 
     RowBox[{"a_", ",", "b_"}]], "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", 
      RowBox[{"a", ",", "b"}]], "'"}], "[", "t", "]"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{
            SubscriptBox["Z", 
             RowBox[{"a", ",", "b"}]], "[", "t", "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{
            SubscriptBox["Z", 
             RowBox[{"a", ",", "b"}]], "[", "t", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{
           RowBox[{"-", "4"}], "\[Pi]"}], ",", "T"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".01", "]"}], ",", "Black"}], "}"}]}]}], 
       "]"}], ",", 
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{
            SubscriptBox["Z", 
             RowBox[{"a", ",", "b"}]], "[", "t", "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{
            SubscriptBox["Z", 
             RowBox[{"a", ",", "b"}]], "[", "t", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "T", ",", 
          RowBox[{"T", "+", "\[Delta]"}]}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             RowBox[{
              SubscriptBox["Z", 
               RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
            RowBox[{"Im", "[", 
             RowBox[{
              SubscriptBox["Z", 
               RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             RowBox[{
              SubscriptBox["Z", 
               RowBox[{"a", ",", "b"}]], "[", 
              RowBox[{"T", "+", "\[Delta]"}], "]"}], "]"}], ",", 
            RowBox[{"Im", "[", 
             RowBox[{
              SubscriptBox["Z", 
               RowBox[{"a", ",", "b"}]], "[", 
              RowBox[{"T", "+", "\[Delta]"}], "]"}], "]"}]}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Blue", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "b"}], "}"}]}], "}"}], "]"}], ",", "Thick", 
         ",", "Magenta", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
             "+", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{
                 SubscriptBox["V", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{
                 SubscriptBox["V", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], 
              "}"}]}]}], "}"}], "]"}], ",", "Thick", ",", "Purple", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", 
                RowBox[{"T", "+", "\[Delta]"}], "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", 
                RowBox[{"T", "+", "\[Delta]"}], "]"}], "]"}]}], "}"}]}], 
           "}"}], "]"}], ",", "Thick", ",", "Red", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
             "+", 
             RowBox[{"a", "*", "\[Delta]", "*", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Re", "[", 
                 RowBox[{
                  SubscriptBox["Z", 
                   RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
                RowBox[{"Im", "[", 
                 RowBox[{
                  SubscriptBox["Z", 
                   RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], 
               "}"}]}]}]}], "}"}], "]"}], ",", "Thick", ",", "Blue", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}], ",", 
               RowBox[{"Im", "[", 
                RowBox[{
                 SubscriptBox["Z", 
                  RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], "}"}], 
             "+", 
             RowBox[{"b", "*", "\[Delta]", "*", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Im", "[", 
                  RowBox[{
                   SubscriptBox["Z", 
                    RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], ",", 
                RowBox[{"Re", "[", 
                 RowBox[{
                  SubscriptBox["Z", 
                   RowBox[{"a", ",", "b"}]], "[", "T", "]"}], "]"}]}], 
               "}"}]}]}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"10", "*", 
        RowBox[{"Abs", "[", "a", "]"}]}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", "Large"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
          "]"}]}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"T", ",", 
        RowBox[{"3", 
         RowBox[{"\[Pi]", "/", "4"}]}]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "\[Pi]"}], "+", ".001"}], ",", 
      RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", ".1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", 
        RowBox[{
         SqrtBox["3"], "/", "2"}]}], "}"}], ",", ".1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]", ",", ".5", ",", ".0001"}], "}"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.615232142658331*^9, 3.6152321968403473`*^9}, {
   3.6152322300102663`*^9, 3.615232262583535*^9}, {3.615232359689225*^9, 
   3.615232543239052*^9}, {3.61523258251823*^9, 3.615232667396571*^9}, {
   3.6152327115162983`*^9, 3.615232769398446*^9}, {3.615233110620949*^9, 
   3.615233112149994*^9}, {3.615233162186776*^9, 3.615233386588831*^9}, {
   3.6152334734261417`*^9, 3.615233481883469*^9}, {3.6152335142485323`*^9, 
   3.6152337508460493`*^9}, {3.6152337815781317`*^9, 3.615233945992831*^9}, 
   3.6297309215824003`*^9, 3.6297342886275053`*^9, {3.629979810497637*^9, 
   3.629979814362752*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["Miscellaneous other Demonstrations",
 FontSize->72,
 FontWeight->"Bold"]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.6297303769432163`*^9, 3.629730407739004*^9}, {
   3.629731187377967*^9, 3.62973119800683*^9}, 3.629731532064155*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Open Sets in the Complex Plane",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->RGBColor[0.6, 0.4, 0.2]]], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578841835287677*^9, 3.578841844280802*^9}, {
   3.578842011043201*^9, 3.578842012381207*^9}, 3.6297312507671022`*^9, 
   3.629734255321185*^9}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "<", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Dashed", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Dashed", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{"z0", ",", 
          FractionBox[
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", 
             RowBox[{
              RowBox[{"z0", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"I", "*", 
               RowBox[{"z0", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], "2"]}], "]"}]}], 
       "}"}], "]"}], ",", 
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", 
            RowBox[{"z0", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "-", 
            RowBox[{"z0", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}], "<", 
        RowBox[{
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", 
             RowBox[{
              RowBox[{"z0", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"I", "*", 
               RowBox[{"z0", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], "2"], ")"}], "^",
          "2"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Yellow"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], "]"}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], "]"}],
         ",", 
        RowBox[{"Text", "[", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], "]"}], 
         "]"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"{", 
        RowBox[{".5", ",", ".5"}], "}"}]}], "}"}], ",", "Locator"}], "}"}]}], 
  "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.569539376429038*^9, 3.569539451618958*^9}, {
   3.5695394928176613`*^9, 3.569539635839932*^9}, {3.569668524801*^9, 
   3.5696685873796167`*^9}, {3.5696686195781403`*^9, 3.569668695355335*^9}, {
   3.569668730707004*^9, 3.569668773160811*^9}, {3.569669009251862*^9, 
   3.569669065801062*^9}, {3.578841930066167*^9, 3.578841978790369*^9}, 
   3.62973125078045*^9, 3.6297314114028*^9, 3.629734255325515*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Stereographic Projection onto Riemann Sphere",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->GrayLevel[0]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578842030971435*^9, 3.578842050386448*^9}, {
   3.578842103444502*^9, 3.5788421136551857`*^9}, 3.6297315320668592`*^9, 
   3.629734263809952*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPi]", "[", 
    RowBox[{"{", 
     RowBox[{"p_", ",", "q_", ",", "r_"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "p"}], 
      RowBox[{
       RowBox[{"p", "^", "2"}], "+", 
       RowBox[{"q", "^", "2"}], "+", "1"}]], ",", 
     FractionBox[
      RowBox[{"2", "q"}], 
      RowBox[{
       RowBox[{"p", "^", "2"}], "+", 
       RowBox[{"q", "^", "2"}], "+", "1"}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"p", "^", "2"}], "+", 
       RowBox[{"q", "^", "2"}], "-", "1"}], 
      RowBox[{
       RowBox[{"p", "^", "2"}], "+", 
       RowBox[{"q", "^", "2"}], "+", "1"}]]}], "}"}]}], ";", 
  RowBox[{"axes", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "t", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "t"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black"}], "}"}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{"equator", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], ",", 
       RowBox[{"Sin", "[", "t", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Magenta"}], "}"}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Grid", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{"axes", ",", "equator", ",", 
          RowBox[{"ContourPlot3D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"x", "^", "2"}], "+", 
              RowBox[{"y", "^", "2"}], "+", 
              RowBox[{"z", "^", "2"}]}], "\[Equal]", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", 
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
            RowBox[{"BoxRatios", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"2", ",", "2", ",", "1"}], "}"}]}], ",", 
            RowBox[{"ContourStyle", "\[Rule]", 
             RowBox[{"Opacity", "[", ".2", "]"}]}], ",", 
            RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
            RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
           "]"}], ",", 
          RowBox[{"ContourPlot3D", "[", 
           RowBox[{
            RowBox[{"z", "\[Equal]", "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", 
              RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
            RowBox[{"BoxRatios", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"2", ",", "2", ",", "1"}], "}"}]}], ",", 
            RowBox[{"ContourStyle", "\[Rule]", 
             RowBox[{"Opacity", "[", ".1", "]"}]}], ",", 
            RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}], ",", 
          RowBox[{"ListPointPlot3D", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Append", "[", 
              RowBox[{"pt", ",", "0"}], "]"}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}], "}"}]}]}], 
           "]"}], ",", 
          RowBox[{"ListPointPlot3D", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[CapitalPi]", "[", 
              RowBox[{"Append", "[", 
               RowBox[{"pt", ",", "0"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}], "}"}]}]}], 
           "]"}], ",", 
          RowBox[{"ParametricPlot3D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Append", "[", 
               RowBox[{"pt", ",", "0"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "t"}], ")"}]}], "+", 
             RowBox[{"t", "*", 
              RowBox[{"\[CapitalPi]", "[", 
               RowBox[{"Append", "[", 
                RowBox[{"pt", ",", "0"}], "]"}], "]"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Thickness", "[", ".007", "]"}], ",", "Green"}], 
               "}"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["x", "1"], ",", 
             SubscriptBox["x", "2"], ",", 
             SubscriptBox["x", "3"]}], "}"}]}], ",", 
          RowBox[{"ViewPoint", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1", ",", "1"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"{", "pt", "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}], 
          ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Magenta", ",", 
             RowBox[{"Circle", "[", "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<\!\(\*
StyleBox[\"real\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"imaginary\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "}"}], "}"}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pt", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}]}], "}"}], ",", "Locator"}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.5788428974194927`*^9, 3.578843162771978*^9}, {
   3.578843299568*^9, 3.578843336558936*^9}, {3.578843371338162*^9, 
   3.578843551156105*^9}, {3.578843602854945*^9, 3.578843647812963*^9}, {
   3.5788437082691727`*^9, 3.578843759266926*^9}, {3.5788438311811733`*^9, 
   3.578843834509243*^9}, {3.578843895881083*^9, 3.578843896261642*^9}, {
   3.578910908571239*^9, 3.578910910613366*^9}, 3.6297315320733128`*^9, {
   3.629731567741102*^9, 3.629731581647678*^9}, 3.62973426382021*^9, 
   3.6299799570790167`*^9, {3.648311880664439*^9, 3.648311885086198*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Cauchy-Riemann Equations",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->RGBColor[0.6, 0.4, 0.2]]], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578841835287677*^9, 3.578841844280802*^9}, {
   3.578842011043201*^9, 3.578842012381207*^9}, 3.6297312507671022`*^9, {
   3.629731634477517*^9, 3.629731641498838*^9}, 3.629734233457138*^9}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "z", ")"}], "=", 
   RowBox[{"sin", "(", "z", ")"}]}], TraditionalForm]]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.578997763818398*^9, 3.578997774069625*^9}, 
   3.62973211279292*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cosh", "[", "y", "]"}], " ", 
    RowBox[{"Sin", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cos", "[", "x", "]"}], " ", 
    RowBox[{"Sinh", "[", "y", "]"}]}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Grid", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ContourPlot", "[", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"x", ",", "y"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}], ",", 
             RowBox[{"Contours", "\[Rule]", "40"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", "pt", "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".04", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{
           "PlotLabel", "\[Rule]", 
            "\"\<Contour Map of u(x,y)=Re(sin(x+\[ImaginaryI]y))\>\""}], ",", 
           
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"real\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"imaginary\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ContourPlot", "[", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"x", ",", "y"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}], ",", 
             RowBox[{"Contours", "\[Rule]", "40"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", "pt", "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".04", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{
           "PlotLabel", "\[Rule]", 
            "\"\<Contour Map of v(x,y)=Im(sin(x+\[ImaginaryI]y))\>\""}], ",", 
           
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"real\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"imaginary\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ContourPlot", "[", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"x", ",", "y"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", ".25"}], ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "+", ".25"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", ".25"}], ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "+", ".25"}]}], "}"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", "pt", "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".04", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"pt", ",", 
                 RowBox[{"pt", "+", 
                  RowBox[{"{", 
                   RowBox[{".05", ",", "0"}], "}"}]}]}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Green", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"pt", ",", 
                 RowBox[{"pt", "+", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", ".05"}], "}"}]}]}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"real\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"imaginary\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ContourPlot", "[", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"x", ",", "y"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", ".25"}], ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "+", ".25"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", ".25"}], ",", 
               RowBox[{
                RowBox[{"pt", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "+", ".25"}]}], "}"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", "pt", "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", ".04", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Green", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"pt", ",", 
                 RowBox[{"pt", "+", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", ".05"}], ",", "0"}], "}"}]}]}], "}"}], 
               "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"pt", ",", 
                 RowBox[{"pt", "+", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", ".05"}], "}"}]}]}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"real\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"imaginary\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "}"}]}], 
      "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pt", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", "Locator"}], "}"}]}], 
   "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.578843955596505*^9, 3.5788441259046917`*^9}, {
   3.578844180319788*^9, 3.578844210137384*^9}, {3.5788442403831787`*^9, 
   3.578844246447917*^9}, {3.5788442901704617`*^9, 3.578844296792795*^9}, {
   3.578844332584869*^9, 3.5788444943893642`*^9}, {3.578960403158187*^9, 
   3.5789605288505793`*^9}, {3.5789606238877783`*^9, 
   3.5789606273933163`*^9}, {3.57898844466113*^9, 3.5789884517641582`*^9}, {
   3.578992529317771*^9, 3.5789925969362164`*^9}, {3.578992636340761*^9, 
   3.578992860595236*^9}, {3.57899289547503*^9, 3.578992905215393*^9}, {
   3.578992942355912*^9, 3.578993028089572*^9}, {3.578993058259736*^9, 
   3.578993103748239*^9}, {3.578993143923461*^9, 3.578993150675565*^9}, {
   3.578993207198451*^9, 3.578993237866006*^9}, {3.578998180015809*^9, 
   3.578998183842793*^9}, {3.612712759890177*^9, 3.612712767962431*^9}, {
   3.612712825381336*^9, 3.612712825697543*^9}, 3.629732112796794*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Derivative as a Local \
\[OpenCurlyDoubleQuote]Amplitwist\[CloseCurlyDoubleQuote]...terminology \
credit to Tristan Needham (from his book \[OpenCurlyDoubleQuote]Visual \
Complex Analysis\[CloseCurlyDoubleQuote])",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->GrayLevel[0]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578842030971435*^9, 3.578842050386448*^9}, {
   3.578842103444502*^9, 3.5788421136551857`*^9}, 3.6297315320668592`*^9, 
   3.629731755530892*^9, 3.629732184292643*^9}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "z", ")"}], "=", 
   RowBox[{"sin", "(", "z", ")"}]}], TraditionalForm]]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.578997763818398*^9, 3.578997774069625*^9}, 
   3.629732184299111*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cosh", "[", "y", "]"}], "*", 
    RowBox[{"Sin", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Cos", "[", "x", "]"}], "*", 
    RowBox[{"Sinh", "[", "y", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"v", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[CapitalPhi]Prime", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "x", "]"}], " ", 
      RowBox[{"Cosh", "[", "y", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "x", "]"}]}], " ", 
      RowBox[{"Sinh", "[", "y", "]"}]}]}], "}"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Grid", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"Text", "[", "\"\<Local Dilation Factor =\>\"", "]"}], ",",
            "Large"}], "]"}], ","}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Item", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{"Norm", "[", 
                RowBox[{"\[CapitalPhi]Prime", "[", "z0", "]"}], "]"}], "]"}], 
              ",", "Large", ",", "Red"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "4"}], "}"}]}], "]"}], "]"}], ","}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{
           "Text", "[", "\"\<Local Twist Amount (in degrees) =\>\"", "]"}], 
           ",", "Large"}], "]"}], ","}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Item", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"180", "/", "\[Pi]"}], ")"}], "*", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[CapitalPhi]Prime", "[", "z0", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}], ",", 
                  RowBox[{
                   RowBox[{"\[CapitalPhi]Prime", "[", "z0", "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
              "Large", ",", "Blue"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "4"}], "}"}]}], "]"}], "]"}], ","}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ParametricPlot", "[", 
            RowBox[{
             RowBox[{"z0", "+", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y"}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "\[Epsilon]"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", "0", ",", "\[Epsilon]"}], "}"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"z0", ",", 
                 RowBox[{"z0", "+", 
                  RowBox[{"{", 
                   RowBox[{"\[Epsilon]", ",", "0"}], "}"}]}]}], "}"}], 
               "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{"z0", ",", 
                 RowBox[{"z0", "+", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "\[Epsilon]"}], "}"}]}]}], "}"}], 
               "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "5"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"TicksStyle", "\[Rule]", "Large"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
               "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], 
                "]"}], "]"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"ParametricPlot", "[", 
            RowBox[{
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"z0", "+", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "\[Epsilon]"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", "0", ",", "\[Epsilon]"}], "}"}], ",", 
             RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
            "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[CapitalPhi]", "[", "z0", "]"}], ",", 
                 RowBox[{"\[CapitalPhi]", "[", 
                  RowBox[{"z0", "+", 
                   RowBox[{"{", 
                    RowBox[{"\[Epsilon]", ",", "0"}], "}"}]}], "]"}]}], "}"}],
                "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[CapitalPhi]", "[", "z0", "]"}], ",", 
                 RowBox[{"\[CapitalPhi]", "[", 
                  RowBox[{"z0", "+", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "\[Epsilon]"}], "}"}]}], "]"}]}], "}"}],
                "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "5"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"TicksStyle", "\[Rule]", "Large"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<real\>\"", ",", "Large", ",", "Italic"}], "]"}], 
               "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<imaginary\>\"", ",", "Large", ",", "Italic"}], 
                "]"}], "]"}]}], "}"}]}]}], "]"}]}], "}"}]}], "}"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", "Locator"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", ".5", ",", ".001"}], "}"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.571397094352776*^9, 3.571397332677354*^9}, {
   3.571398757542033*^9, 3.571398938478994*^9}, {3.571737446208805*^9, 
   3.571737446593569*^9}, {3.5717430350367756`*^9, 3.5717430518209767`*^9}, {
   3.571744326224842*^9, 3.5717443284552107`*^9}, {3.571744684331441*^9, 
   3.5717448059493837`*^9}, {3.571748060331171*^9, 3.571748061178137*^9}, {
   3.578997665753585*^9, 3.578997709452792*^9}, 3.578997758532981*^9, {
   3.578997804005031*^9, 3.578997851676342*^9}, {3.5789978817118473`*^9, 
   3.5789978882434607`*^9}, {3.629731822461474*^9, 3.6297318875140553`*^9}, {
   3.62973191889354*^9, 3.62973199331563*^9}, {3.6297320288891068`*^9, 
   3.6297320499983273`*^9}, 3.629732184304414*^9, {3.6483119050954638`*^9, 
   3.648311923756899*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solving Laplace\[CloseCurlyQuote]s Equation",
 FontSize->36,
 FontWeight->"Bold",
 FontColor->RGBColor[0.6, 0.4, 0.2]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578842030971435*^9, 3.578842050386448*^9}, {
   3.578842103444502*^9, 3.5788421136551857`*^9}, 3.6297315320668592`*^9, 
   3.629731755530892*^9, {3.629732184292643*^9, 3.629732232505739*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Arg", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"I", "*", "y"}]}], ")"}], "+", "1"}], "]"}]}], "+", 
    RowBox[{"Arg", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"I", "*", "y"}]}], ")"}], "-", "2"}], "]"}]}]}], ";", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"Contours", "\[Rule]", "50"}], ",", 
        RowBox[{"Frame", "\[Rule]", "False"}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"RegionFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{"y", "\[GreaterEqual]", "0"}]}], "]"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Plot3D", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", 
           RowBox[{"x", ",", "y"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Opacity", "[", ".8", "]"}]}], ",", 
          RowBox[{"RegionFunction", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
             RowBox[{"y", "\[GreaterEqual]", "0"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "t", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "t"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}], ",", 
        RowBox[{"ListPointPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"2", ",", "3", ",", 
             RowBox[{"Pi", "/", "4"}]}], "}"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"Red", ",", 
              RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}], "}"}]}]}], 
         "]"}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "\[Phi]"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "}"}], "}"}], 
   "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellChangeTimes->{{3.572088527461213*^9, 3.5720885745476313`*^9}, {
   3.5720886165789757`*^9, 3.5720887431882143`*^9}, {3.5720888476458063`*^9, 
   3.572088895588756*^9}, 3.5720899526479063`*^9, {3.572090017419492*^9, 
   3.5720901483167*^9}, {3.572090189936036*^9, 3.5720902285248833`*^9}, {
   3.572091075126327*^9, 3.572091132237771*^9}, 3.629732232510757*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Complex Integration, viewed as ",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{" ", "\[ScriptCapitalC]"}]], 
     RowBox[{
      RowBox[{"f", "(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", 
       RowBox[{" ", "\[ScriptCapitalC]"}]], 
      RowBox[{
       RowBox[{"\[LeftAngleBracket]", 
        RowBox[{"u", ",", 
         RowBox[{"-", "v"}]}], "\[RightAngleBracket]"}], "\[CenterDot]", 
       RowBox[{"\[DifferentialD]", "s"}]}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubscriptBox["\[Integral]", 
        RowBox[{" ", "\[ScriptCapitalC]"}]], 
       RowBox[{
        RowBox[{"\[LeftAngleBracket]", 
         RowBox[{"v", ",", "u"}], "\[RightAngleBracket]"}], "\[CenterDot]", 
        RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]}], TraditionalForm]],
  FontSize->36,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[" ",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578842030971435*^9, 3.578842050386448*^9}, {
   3.578842103444502*^9, 3.5788421136551857`*^9}, 3.6297315320668592`*^9, 
   3.629731755530892*^9, {3.629732184292643*^9, 3.629732232505739*^9}, {
   3.629732264935988*^9, 3.629732290497666*^9}, 3.629732382299699*^9, {
   3.629890013292109*^9, 3.629890014271055*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "z", ")"}], "=", 
   SuperscriptBox["z", "2"]}], TraditionalForm]]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.5790098674275084`*^9, 3.579009870093649*^9}, 
   3.629732402304603*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "^", "2"}], "-", 
    RowBox[{"y", "^", "2"}]}]}], ";", 
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"2", "x", "*", "y"}]}], ";", 
  RowBox[{
   RowBox[{"x", "[", "t_", "]"}], ":=", 
   RowBox[{"Cos", "[", "t", "]"}]}], ";", 
  RowBox[{
   RowBox[{"y", "[", "t_", "]"}], ":=", 
   RowBox[{"Sin", "[", "t", "]"}]}], ";", 
  RowBox[{
   RowBox[{"z", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], ",", 
     RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"uNegvBackGround", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"VectorPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"v", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"VectorStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"z", "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Magenta", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"z", "[", "\[Theta]", "]"}], ",", 
              RowBox[{
               RowBox[{"z", "[", "\[Theta]", "]"}], "+", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"u", "[", 
                  RowBox[{
                   RowBox[{"x", "[", "\[Theta]", "]"}], ",", 
                   RowBox[{"y", "[", "\[Theta]", "]"}]}], "]"}], ",", 
                 RowBox[{"-", 
                  RowBox[{"v", "[", 
                   RowBox[{
                    RowBox[{"x", "[", "\[Theta]", "]"}], ",", 
                    RowBox[{"y", "[", "\[Theta]", "]"}]}], "]"}]}]}], 
                "}"}]}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "40"}]}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<The vector field \[LeftAngleBracket]u,-v\[RightAngleBracket] and \
\[ScriptCapitalC]\>\""}]}], "]"}]}], ";", 
  RowBox[{"vuBackGround", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"VectorPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
       RowBox[{"VectorStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"z", "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Magenta", ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"z", "[", "\[Theta]", "]"}], ",", 
              RowBox[{
               RowBox[{"z", "[", "\[Theta]", "]"}], "+", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"v", "[", 
                  RowBox[{
                   RowBox[{"x", "[", "\[Theta]", "]"}], ",", 
                   RowBox[{"y", "[", "\[Theta]", "]"}]}], "]"}], ",", 
                 RowBox[{"u", "[", 
                  RowBox[{
                   RowBox[{"x", "[", "\[Theta]", "]"}], ",", 
                   RowBox[{"y", "[", "\[Theta]", "]"}]}], "]"}]}], "}"}]}]}], 
             "}"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "40"}]}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<The vector field \[LeftAngleBracket]v,u\[RightAngleBracket] and \
\[ScriptCapitalC]\>\""}]}], "]"}]}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"Grid", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{"uNegvBackGround", ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"z", "[", "b", "]"}], ",", 
                 RowBox[{
                  RowBox[{"z", "[", "b", "]"}], "+", 
                  RowBox[{
                   RowBox[{"z", "'"}], "[", "b", "]"}]}]}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"u", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], ",", 
                  RowBox[{"y", "[", "t", "]"}]}], "]"}], ",", 
                RowBox[{"-", 
                 RowBox[{"v", "[", 
                  RowBox[{
                   RowBox[{"x", "[", "t", "]"}], ",", 
                   RowBox[{"y", "[", "t", "]"}]}], "]"}]}]}], "}"}], ".", 
              RowBox[{
               RowBox[{"z", "'"}], "[", "t", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", 
               RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Thick", ",", "Magenta"}], "}"}]}]}], "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"b", ",", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"u", "[", 
                    RowBox[{
                    RowBox[{"x", "[", "b", "]"}], ",", 
                    RowBox[{"y", "[", "b", "]"}]}], "]"}], ",", 
                   RowBox[{"-", 
                    RowBox[{"v", "[", 
                    RowBox[{
                    RowBox[{"x", "[", "b", "]"}], ",", 
                    RowBox[{"y", "[", "b", "]"}]}], "]"}]}]}], "}"}], ".", 
                 RowBox[{
                  RowBox[{"z", "'"}], "[", "b", "]"}]}]}], "}"}], "}"}], ",", 
             
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Black", ",", 
                RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black", ",", "Dashed", ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"2", "\[Pi]"}], ",", "0"}], "}"}]}], "}"}], 
               "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<t\>\"", ",", 
              "\"\<\[LeftAngleBracket]u,-v\[RightAngleBracket]\[CenterDot]\!\(\
\*SuperscriptBox[\(z\), \(\(\\\ \)\(\[Prime]\)\)]\)(t)\>\""}], "}"}]}]}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{"vuBackGround", ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black", ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"z", "[", "b", "]"}], ",", 
                 RowBox[{
                  RowBox[{"z", "[", "b", "]"}], "+", 
                  RowBox[{
                   RowBox[{"z", "'"}], "[", "b", "]"}]}]}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"v", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], ",", 
                  RowBox[{"y", "[", "t", "]"}]}], "]"}], ",", 
                RowBox[{"u", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], ",", 
                  RowBox[{"y", "[", "t", "]"}]}], "]"}]}], "}"}], ".", 
              RowBox[{
               RowBox[{"z", "'"}], "[", "t", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", 
               RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Thick", ",", "Magenta"}], "}"}]}]}], "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"{", 
               RowBox[{"b", ",", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"v", "[", 
                    RowBox[{
                    RowBox[{"x", "[", "b", "]"}], ",", 
                    RowBox[{"y", "[", "b", "]"}]}], "]"}], ",", 
                   RowBox[{"u", "[", 
                    RowBox[{
                    RowBox[{"x", "[", "b", "]"}], ",", 
                    RowBox[{"y", "[", "b", "]"}]}], "]"}]}], "}"}], ".", 
                 RowBox[{
                  RowBox[{"z", "'"}], "[", "b", "]"}]}]}], "}"}], "}"}], ",", 
             
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Black", ",", 
                RowBox[{"PointSize", "[", ".02", "]"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black", ",", "Dashed", ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"2", "\[Pi]"}], ",", "0"}], "}"}]}], "}"}], 
               "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<t\>\"", ",", 
              "\"\<\[LeftAngleBracket]v,u\[RightAngleBracket]\[CenterDot]\!\(\
\*SuperscriptBox[\(z\), \(\(\\\ \)\(\[Prime]\)\)]\)(t)\>\""}], "}"}]}]}], 
          "]"}]}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0", ",", 
      RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.},
 CellChangeTimes->{{3.573893043394154*^9, 3.573893151566481*^9}, {
   3.573893727290409*^9, 3.5738938422564363`*^9}, {3.5738938819642553`*^9, 
   3.57389416015145*^9}, {3.573894195457864*^9, 3.573894240632535*^9}, {
   3.573894284934155*^9, 3.5738943153645563`*^9}, {3.5738946144231377`*^9, 
   3.573894701488826*^9}, {3.5738948351558657`*^9, 3.573894839367878*^9}, {
   3.57389489348249*^9, 3.573894911034666*^9}, {3.573894970310869*^9, 
   3.573894970450787*^9}, {3.573895368736883*^9, 3.573895486782178*^9}, {
   3.573895541491087*^9, 3.573895545679995*^9}, {3.573895575728835*^9, 
   3.573895600758016*^9}, {3.573896535041697*^9, 3.573896537921093*^9}, {
   3.573981074326421*^9, 3.573981129367975*^9}, {3.573981165885128*^9, 
   3.573981280599236*^9}, 3.5745858699456177`*^9, 3.6297323823042507`*^9, {
   3.629732440808423*^9, 3.629732454522174*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Complex Integration, viewed as ",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{" ", "\[ScriptCapitalC]"}]], 
     RowBox[{
      RowBox[{"f", "(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], 
    StyleBox["=",
     FontSize->36], 
    StyleBox[
     RowBox[{
      RowBox[{
       SubscriptBox["\[Integral]", 
        RowBox[{" ", "\[ScriptCapitalC]"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", "+", 
          RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", " ", "F"}], "=", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", " ", "U"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", "V"}]}]}]}],
     FontSize->36]}], TraditionalForm]],
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[",",
  FontSize->36,
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox[" ",
  FontSize->36],
 StyleBox["including the calculation of these changes as limits near branch \
cuts",
  FontSize->36,
  FontWeight->"Bold",
  FontColor->RGBColor[0.6, 0.4, 0.2]]
}], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.565107110045114*^9, 3.56510711728935*^9}, {
   3.566249649560296*^9, 3.5662496513664513`*^9}, {3.566250644834818*^9, 
   3.566250649747299*^9}, {3.578839004113016*^9, 3.578839007599032*^9}, {
   3.578841547217073*^9, 3.5788415523399763`*^9}, {3.578841743076519*^9, 
   3.578841769882372*^9}, {3.578842030971435*^9, 3.578842050386448*^9}, {
   3.578842103444502*^9, 3.5788421136551857`*^9}, 3.6297315320668592`*^9, 
   3.629731755530892*^9, {3.629732184292643*^9, 3.629732232505739*^9}, {
   3.629732264935988*^9, 3.629732290497666*^9}, 3.629732382299699*^9, {
   3.6297324845488358`*^9, 3.629732484548915*^9}, 3.6297327176940536`*^9, {
   3.629890017992181*^9, 3.629890019159213*^9}, {3.629890140658546*^9, 
   3.629890158419261*^9}, {3.629890213417005*^9, 3.629890230040373*^9}, {
   3.6299050659697*^9, 3.629905069901404*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "z", ")"}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]]}], TraditionalForm]]]], "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.57901063608957*^9, 3.5790106518793583`*^9}, 
   3.6297327176980352`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], ":=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "I"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]]}], ";", 
  RowBox[{"\[Integral]", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.575908240202422*^9, 3.5759082489680233`*^9}, {
   3.579010663180891*^9, 3.5790106634811783`*^9}, 3.6297327177011843`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "t_", "]"}], ":=", 
   RowBox[{"I", "+", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"z2", "[", "t_", "]"}], ":=", 
   RowBox[{"2", "+", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"z3", "[", "t_", "]"}], ":=", 
   RowBox[{"3", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{3.629732717708482*^9}],

Cell[BoxData[
 RowBox[{"Residue", "[", 
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "I"}], "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{3.629732717712061*^9}],

Cell[BoxData[
 RowBox[{"2", "\[Pi]", "*", "\[ImaginaryI]", "*", 
  RowBox[{"Residue", "[", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "I"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{3.579968583836769*^9, 3.629732717719391*^9}],

Cell[BoxData[
 RowBox[{"Residue", "[", 
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.579968423598566*^9, 3.579968423742008*^9}, 
   3.629732717727408*^9}],

Cell[BoxData[
 RowBox[{"2", "\[Pi]", "*", "\[ImaginaryI]", "*", 
  RowBox[{"Residue", "[", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{
  3.579968583836769*^9, {3.579968634621608*^9, 3.579968634717799*^9}, 
   3.629732717735145*^9}],

Cell[BoxData[{
 RowBox[{"N", "[", 
  RowBox[{"2", "\[Pi]", "*", "\[ImaginaryI]", "*", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"f", "[", "z", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "I"}], "}"}]}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"z1", "[", "t", "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{"z1", "'"}], "[", "t", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.57901073174374*^9, 3.57901081581361*^9}, 
   3.62973271774257*^9}],

Cell[BoxData[{
 RowBox[{"N", "[", 
  RowBox[{"2", "\[Pi]", "*", "\[ImaginaryI]", "*", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"f", "[", "z", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"z2", "[", "t", "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{"z2", "'"}], "[", "t", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.57901073174374*^9, 3.579010765667272*^9}, {
   3.57901082382333*^9, 3.579010831533471*^9}, 3.629732717753832*^9}],

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"z3", "[", "t", "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{"z3", "'"}], "[", "t", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.57901084290123*^9, 3.579010844300913*^9}, 
   3.629732717765387*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "t_", "]"}], ":=", 
   RowBox[{"I", "+", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"z2", "[", "t_", "]"}], ":=", 
   RowBox[{"2", "+", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"z3", "[", "t_", "]"}], ":=", 
   RowBox[{"3", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"I", "*", "t"}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], ":=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "I"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]]}], ";", 
  RowBox[{
   RowBox[{"F", "[", "z_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "5"], "-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}], ")"}], " ", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "2"}], "+", "z"}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "z"}]}]], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "5"], "+", 
       FractionBox["\[ImaginaryI]", "10"]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", "z"}], ")"}], "2"], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "5"], "+", 
       FractionBox["\[ImaginaryI]", "10"]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", 
       SuperscriptBox["z", "2"]}], "]"}]}]}]}], ";", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "t", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "t"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}], ",", 
        RowBox[{"Plot3D", "[", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"F", "[", 
            RowBox[{"x", "+", 
             RowBox[{"I", "*", "y"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Re", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z1", "[", "t", "]"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Re", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z2", "[", "t", "]"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z3", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z3", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Re", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z3", "[", "t", "]"}], "]"}], "]"}]}], "}"}]}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", "Red"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", "Blue"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", 
               RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}]}], 
         "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Re(z)\>\"", ",", "Large"}], "]"}], "]"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Im(z)\>\"", ",", "Large"}], "]"}], "]"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Re(F(z))\>\"", ",", "Large"}], "]"}], "]"}]}], 
          "}"}]}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "t", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "t"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}], ",", 
        RowBox[{"Plot3D", "[", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"F", "[", 
            RowBox[{"x", "+", 
             RowBox[{"I", "*", "y"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z1", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z1", "[", "t", "]"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z2", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z2", "[", "t", "]"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"z3", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"z3", "[", "t", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"F", "[", 
                RowBox[{"z3", "[", "t", "]"}], "]"}], "]"}]}], "}"}]}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", "Red"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", "Blue"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Thickness", "[", ".02", "]"}], ",", 
               RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}]}], 
         "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Re(z)\>\"", ",", "Large"}], "]"}], "]"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Im(z)\>\"", ",", "Large"}], "]"}], "]"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Im(F(z))\>\"", ",", "Large"}], "]"}], "]"}]}], 
          "}"}]}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]}], "]"}]}], "}"}], "}"}],
    "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.},
 CellChangeTimes->{{3.579010675334*^9, 3.579010715435376*^9}, {
   3.579968336751499*^9, 3.579968349198183*^9}, {3.579969065850773*^9, 
   3.579969066870925*^9}, {3.579969197100963*^9, 3.579969232884858*^9}, {
   3.579969272928054*^9, 3.579969308173107*^9}, {3.5799693413346148`*^9, 
   3.57996934261413*^9}, {3.629732521104718*^9, 3.629732641143407*^9}, {
   3.6297326723862*^9, 3.629732675410986*^9}, 3.629732717773817*^9, {
   3.648311949950575*^9, 3.6483119538208437`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1179, 643},
WindowMargins->{{14, Automatic}, {Automatic, 74}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 22, 280, "Subsection"],
Cell[CellGroupData[{
Cell[1453, 46, 518, 11, 120, "Section"],
Cell[CellGroupData[{
Cell[1996, 61, 765, 19, 129, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[2764, 82, 24790, 603, 672, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[27591, 690, 618, 14, 110, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[28212, 706, 7486, 188, 196, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[35735, 899, 721, 15, 247, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[36459, 916, 11862, 338, 301, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[48358, 1259, 515, 13, 110, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[48876, 1274, 6809, 186, 216, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[55722, 1465, 2533, 84, 312, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[58258, 1551, 10964, 299, 250, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[69237, 1853, 304, 5, 193, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[69566, 1862, 662, 11, 55, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[70231, 1875, 3801, 103, 199, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[74069, 1983, 664, 11, 63, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[74736, 1996, 8382, 220, 295, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[83155, 2221, 702, 11, 55, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[83860, 2234, 303, 7, 44, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[84166, 2243, 9634, 244, 325, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[93837, 2492, 858, 14, 107, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[94698, 2508, 304, 7, 44, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[95005, 2517, 9171, 232, 250, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[104213, 2754, 720, 11, 63, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}],
Cell[104936, 2767, 4038, 104, 148, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[109011, 2876, 1857, 48, 118, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[110871, 2926, 300, 7, 44, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}],
Cell[111174, 2935, 14045, 362, 335, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10003.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[125256, 3302, 2217, 58, 162, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[127476, 3362, 436, 12, 54, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[127915, 3376, 565, 16, 51, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[128483, 3394, 625, 21, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[129111, 3417, 256, 7, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[129370, 3426, 336, 8, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[129709, 3436, 306, 8, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[130018, 3446, 389, 10, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[130410, 3458, 705, 20, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[131118, 3480, 752, 20, 46, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[131873, 3502, 452, 13, 28, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}],
Cell[132328, 3517, 10802, 294, 314, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10004.}]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
